from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Description import Description
from ..l0.Sequence import Sequence
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..clv.Geometry import Geometry
    from ..clv.SpatialObject import SpatialObject
    from ..mu.Value import Value
    from ..Thing import Thing
    from .RouteType import RouteType
    from .Stage import Stage


class Route(Description, Sequence):
    __type__ = ROUTE["Route"]

    hasLength: List[Value] = None
    hasMember: List[Stage] = None
    crosses: List[SpatialObject] = None
    isDeviationOf: List[Thing] = None
    isPrefRouteOf: List[Thing] = None
    isRouteOf: List[Thing] = None
    hasGeometry: Geometry = None
    hasRouteType: RouteType = None
    routeLongName: List[Literal] = None
    routeShortName: List[Literal] = None
    routelLength: List[Literal] = None
    description: List[Literal] = None
    routeEstDuration: List[Literal] = None
    numberOfStages: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasLength:
            for hasLength in self.hasLength:
                g.add((self.uriRef, ROUTE["hasLength"], hasLength.uriRef))

        if self.hasMember:
            for hasMember in self.hasMember:
                g.add((self.uriRef, L0["hasMember"], hasMember.uriRef))

        if self.crosses:
            for crosses in self.crosses:
                g.add((self.uriRef, ROUTE["crosses"], crosses.uriRef))

        if self.isDeviationOf:
            for isDeviationOf in self.isDeviationOf:
                g.add(
                    (self.uriRef, ROUTE["isDeviationOf"], isDeviationOf.uriRef))

        if self.isPrefRouteOf:
            for isPrefRouteOf in self.isPrefRouteOf:
                g.add(
                    (self.uriRef, ROUTE["isPrefRouteOf"], isPrefRouteOf.uriRef))

        if self.isRouteOf:
            for isRouteOf in self.isRouteOf:
                g.add((self.uriRef, ROUTE["isRouteOf"], isRouteOf.uriRef))

        if self.hasGeometry:
            g.add((self.uriRef, CLV["hasGeometry"], self.hasGeometry.uriRef))

        if self.hasRouteType:
            g.add((self.uriRef, ROUTE["hasRouteType"],
                  self.hasRouteType.uriRef))

        if self.routeLongName:
            for routeLongName in self.routeLongName:
                g.add((self.uriRef, ROUTE["routeLongName"], routeLongName))

        if self.routeShortName:
            for routeShortName in self.routeShortName:
                g.add((self.uriRef, ROUTE["routeShortName"], routeShortName))

        if self.routelLength:
            for routelLength in self.routelLength:
                g.add((self.uriRef, ROUTE["routelLength"], routelLength))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.routeEstDuration:
            for routeEstDuration in self.routeEstDuration:
                g.add(
                    (self.uriRef, ROUTE["routeEstDuration"], routeEstDuration))

        if self.numberOfStages:
            g.add((self.uriRef, ROUTE["numberOfStages"], self.numberOfStages))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..Thing import Thing


class AccessCondition(Characteristic):
    __type__ = ACOND["AccessCondition"]

    isAccessConditionOf: List[Thing] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isAccessConditionOf:
            for isAccessConditionOf in self.isAccessConditionOf:
                g.add((self.uriRef, ACOND["isAccessConditionOf"],
                       isAccessConditionOf.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Topic import Topic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .PublicEvent import PublicEvent


class PublicEventTypology(Topic):
    __type__ = CPEV["PublicEventTypology"]

    isPublicEventTypologyOf: List[PublicEvent] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isPublicEventTypologyOf:
            for isPublicEventTypologyOf in self.isPublicEventTypologyOf:
                g.add(
                    (self.uriRef, CPEV["isPublicEventTypologyOf"], isPublicEventTypologyOf.uriRef))



from ontopia_py.iot.MonitoringFacility import MonitoringFacility
from ..ns import *
from .MonitoringFacility import MonitoringFacility


class Actuator(MonitoringFacility):
    __type__ = IOT["Actuator"]



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .AdminUnitComponent import AdminUnitComponent

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class Province(AdminUnitComponent):
    __type__ = CLV["Province"]

    acronym: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.acronym:
            for acronym in self.acronym:
                g.add((self.uriRef, CLV["acronym"], acronym))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..route.TripPlan import TripPlan

if TYPE_CHECKING:
    from rdflib import Graph

    from ..ti.TemporalEntity import TemporalEntity
    from .Path import Path
    from .TravellingMethod import TravellingMethod


class PathPlan(TripPlan):
    __type__ = PATHS["PathPlan"]

    bestWhen: List[TemporalEntity] = None
    hasTravellingMethod: TravellingMethod = None
    isTripPlanOf: Path = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.bestWhen:
            for bestWhen in self.bestWhen:
                g.add((self.uriRef, PATHS["bestWhen"], bestWhen.uriRef))

        if self.hasTravellingMethod:
            g.add(
                (self.uriRef, PATHS["hasTravellingMethod"], self.hasTravellingMethod.uriRef))

        if self.isTripPlanOf:
            g.add(
                (self.uriRef, ROUTE["isTripPlanOf"], self.isTripPlanOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Entity import Entity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..clv.Address import Address
    from ..clv.Geometry import Geometry
    from ..sm.Image import Image
    from ..ti.TimeInterval import TimeInterval
    from .MultiplePointOfInterest import MultiplePointOfInterest
    from .POINameInTime import POINameInTime
    from .PointOfInterestCategory import PointOfInterestCategory
    from .POIState import POIState


class PointOfInterest(Entity):
    __type__ = POI["PointOfInterest"]

    hasPOICategory: List[PointOfInterestCategory] = []
    hasAddress: List[Address] = []
    hasPOINameInITime: List[POINameInTime] = None
    hasImage: List[Image] = None
    atTime: List[TimeInterval] = None
    hasGeometry: Geometry = None
    hasPOIState: POIState = None
    isIncludedInPOI: MultiplePointOfInterest = None
    POIofficialName: List[Literal] = None
    POIdescription: List[Literal] = None
    POIID: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasPOICategory:
            for hasPOICategory in self.hasPOICategory:
                g.add(
                    (self.uriRef, POI["hasPOICategory"], hasPOICategory.uriRef))

        if self.hasAddress:
            for hasAddress in self.hasAddress:
                g.add((self.uriRef, CLV["hasAddress"], hasAddress.uriRef))

        if self.hasPOINameInITime:
            for hasPOINameInITime in self.hasPOINameInITime:
                g.add(
                    (self.uriRef, POI["hasPOINameInITime"], hasPOINameInITime.uriRef))

        if self.hasImage:
            for hasImage in self.hasImage:
                g.add(
                    (self.uriRef, SM["hasImage"], hasImage.uriRef))

        if self.atTime:
            for atTime in self.atTime:
                g.add(
                    (self.uriRef, TI["atTime"], atTime.uriRef))

        if self.hasGeometry:
            g.add((self.uriRef, CLV["hasGeometry"], self.hasGeometry.uriRef))

        if self.hasPOIState:
            g.add((self.uriRef, CLV["hasPOIState"], self.hasPOIState.uriRef))

        if self.isIncludedInPOI:
            g.add((self.uriRef, CLV["isIncludedInPOI"],
                  self.isIncludedInPOI.uriRef))

        if self.POIofficialName:
            for POIofficialName in self.POIofficialName:
                g.add((self.uriRef, POI["POIofficialName"], POIofficialName))

        if self.POIdescription:
            for POIdescription in self.POIdescription:
                g.add((self.uriRef, POI["POIdescription"], POIdescription))

        if self.POIID:
            g.add((self.uriRef, POI["POIID"], self.POIID))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .MonitoringFacility import MonitoringFacility

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Observation import Observation
    from .ObservationCollection import ObservationCollection


class Sensor(MonitoringFacility):
    __type__ = IOT["Sensor"]

    makesObservation: List[Observation] = None
    makesObservationCollection: List[ObservationCollection] = None
    description: List[Literal] = None
    identifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.makesObservation:
            for makesObservation in self.makesObservation:
                g.add(
                    (self.uriRef, IOT["makesObservation"], makesObservation.uriRef))

        if self.makesObservationCollection:
            for makesObservationCollection in self.makesObservationCollection:
                g.add(
                    (self.uriRef, IOT["makesObservationCollection"], makesObservationCollection.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from ..ro.TimeIndexedRole import TimeIndexedRole

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Organization import Organization


class Employment(TimeIndexedRole):
    __type__ = COV["Employment"]

    employmentFor: Organization = None
    remuneration: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.employmentFor:
            g.add((self.uriRef, COV["employmentFor"],
                  self.employmentFor.uriRef))

        if self.remuneration:
            g.add((self.uriRef, COV["remuneration"],
                  self.remuneration))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.EventOrSituation import EventOrSituation
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Organization import Organization


class ChangeEvent(EventOrSituation):
    __type__ = COV["ChangeEvent"]

    orginalOrganization: List[Organization] = None
    resultingOrganization: List[Organization] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.orginalOrganization:
            for orginalOrganization in self.orginalOrganization:
                g.add(
                    (self.uriRef, COV["orginalOrganization"], orginalOrganization.uriRef))

        if self.resultingOrganization:
            for resultingOrganization in self.resultingOrganization:
                g.add(
                    (self.uriRef, COV["resultingOrganization"], resultingOrganization.uriRef))

        if self.description:
            for description in self.description:
                g.add(
                    (self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..cov.Organization import Organization
    from ..sm.WebSite import WebSite
    from .PathPlan import PathPlan
    from .PathTheme import PathTheme
    from .Pathway import Pathway
    from .QuantifiedPathwayPaving import QuantifiedPathwayPaving


class Path(Description):
    __type__ = PATHS["Path"]

    hasGovernanceOrgan: List[Organization] = None
    hasRoute: List[Pathway] = None
    hasTripPlan: List[PathPlan] = None
    hasWebSite: List[WebSite] = None
    encountersPath: List[Path] = None
    hasAltRoute: List[Pathway] = None
    hasDeviation: List[Pathway] = None
    hasQuantifiedPathwayPaving: List[QuantifiedPathwayPaving] = None
    hasTheme: List[PathTheme] = None
    hasPrefRoute: Pathway = None
    description: List[Literal] = None
    name: List[Literal] = None
    pathNumber: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasGovernanceOrgan:
            for hasGovernanceOrgan in self.hasGovernanceOrgan:
                g.add(
                    (self.uriRef, PATHS["hasGovernanceOrgan"], hasGovernanceOrgan.uriRef))

        if self.hasRoute:
            for hasRoute in self.hasRoute:
                g.add((self.uriRef, ROUTE["hasRoute"], hasRoute.uriRef))

        if self.hasTripPlan:
            for hasTripPlan in self.hasTripPlan:
                g.add((self.uriRef, ROUTE["hasTripPlan"], hasTripPlan.uriRef))

        if self.hasWebSite:
            for hasWebSite in self.hasWebSite:
                g.add((self.uriRef, SM["hasWebSite"], hasWebSite.uriRef))

        if self.encountersPath:
            for encountersPath in self.encountersPath:
                g.add(
                    (self.uriRef, PATHS["encountersPath"], encountersPath.uriRef))

        if self.hasAltRoute:
            for hasAltRoute in self.hasAltRoute:
                g.add((self.uriRef, ROUTE["hasAltRoute"], hasAltRoute.uriRef))

        if self.hasDeviation:
            for hasDeviation in self.hasDeviation:
                g.add(
                    (self.uriRef, ROUTE["hasDeviation"], hasDeviation.uriRef))

        if self.hasQuantifiedPathwayPaving:
            for hasQuantifiedPathwayPaving in self.hasQuantifiedPathwayPaving:
                g.add(
                    (self.uriRef, PATHS["hasQuantifiedPathwayPaving"], hasQuantifiedPathwayPaving.uriRef))

        if self.hasTheme:
            for hasTheme in self.hasTheme:
                g.add((self.uriRef, PATHS["hasTheme"], hasTheme.uriRef))

        if self.hasPrefRoute:
            g.add((self.uriRef, ROUTE["hasPrefRoute"],
                  self.hasPrefRoute.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.pathNumber:
            for pathNumber in self.pathNumber:
                g.add((self.uriRef, PATHS["pathNumber"], pathNumber))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..Thing import Thing


class AdmissionType(Characteristic):
    __type__ = ACOND["AdmissionType"]

    name: List[Literal] = None
    description: List[Literal] = None
    isAdmissionTypeOf: List[Thing]

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isAdmissionTypeOf:
            for isAdmissionTypeOf in self.isAdmissionTypeOf:
                g.add(
                    (self.uriRef, ACOND["isAdmissionTypeOf"], isAdmissionTypeOf.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .OSDCriterion import OSDCriterion
    from .OSDFeature import OSDFeature


class OfferedServiceDescription(Object):
    __type__ = ACCO["OfferedServiceDescription"]

    maxValue: List[Literal] = None
    minValue: List[Literal] = None
    totalValue: List[Literal] = None
    genericValue: Literal = None
    hasOSDCriterion: List[OSDCriterion] = None
    hasOSDFeature: List[OSDFeature] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.maxValue:
            for maxValue in self.maxValue:
                g.add((self.uriRef, ACCO["maxValue"], maxValue))

        if self.minValue:
            for minValue in self.minValue:
                g.add((self.uriRef, ACCO["minValue"], minValue))

        if self.totalValue:
            for totalValue in self.totalValue:
                g.add((self.uriRef, ACCO["totalValue"], totalValue))

        if self.genericValue:
            g.add((self.uriRef, ACCO["genericValue"], self.genericValue))

        if self.hasOSDCriterion:
            for hasOSDCriterion in self.hasOSDCriterion:
                g.add(
                    (self.uriRef, ACCO["hasOSDCriterion"], hasOSDCriterion.uriRef))

        if self.hasOSDFeature:
            for hasOSDFeature in self.hasOSDFeature:
                g.add(
                    (self.uriRef, ACCO["hasOSDFeature"], hasOSDFeature.uriRef))



from .CarPark import CarPark
from .CarParkTypology import CarParkTypology
from .CarSharingCarPark import CarSharingCarPark
from .ParkAndRide import ParkAndRide
from .RotatingCarPark import RotatingCarPark
from .TerminalCarPark import TerminalCarPark



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..route.Stage import Stage

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..acco.Accommodation import Accommodation
    from ..poi.PointOfInterest import PointOfInterest
    from .Restaurant import Restaurant
    from .Signposting import Signposting
    from .SupportService import SupportService


class PathStage(Stage):
    __type__ = PATHS["PathStage"]

    hasSignposting: List[Signposting] = None
    hasSupportService: List[SupportService] = None
    hasNearbyAccommodation: List[Accommodation] = None
    hasNearbyPointOfInterest: List[PointOfInterest] = None
    hasNearbyRestaurant: List[Restaurant] = None
    encountersPathStage: List[PathStage] = None
    stageNumber: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasSignposting:
            for hasSignposting in self.hasSignposting:
                g.add(
                    (self.uriRef, PATHS["hasSignposting"], hasSignposting.uriRef))

        if self.hasSupportService:
            for hasSupportService in self.hasSupportService:
                g.add(
                    (self.uriRef, PATHS["hasSupportService"], hasSupportService.uriRef))

        if self.hasNearbyAccommodation:
            for hasNearbyAccommodation in self.hasNearbyAccommodation:
                g.add(
                    (self.uriRef, PATHS["hasNearbyAccommodation"], hasNearbyAccommodation.uriRef))

        if self.hasNearbyPointOfInterest:
            for hasNearbyPointOfInterest in self.hasNearbyPointOfInterest:
                g.add(
                    (self.uriRef, PATHS["hasNearbyPointOfInterest"], hasNearbyPointOfInterest.uriRef))

        if self.hasNearbyRestaurant:
            for hasNearbyRestaurant in self.hasNearbyRestaurant:
                g.add(
                    (self.uriRef, PATHS["hasNearbyRestaurant"], hasNearbyRestaurant.uriRef))

        if self.encountersPathStage:
            for encountersPathStage in self.encountersPathStage:
                g.add(
                    (self.uriRef, PATHS["encountersPathStage"], encountersPathStage.uriRef))

        if self.stageNumber:
            for stageNumber in self.stageNumber:
                g.add((self.uriRef, PATHS["stageNumber"], stageNumber))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .SpatialObject import SpatialObject

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..Thing import Thing
    from .Geometry import Geometry


class Feature(SpatialObject):
    __type__ = CLV["Feature"]

    hasGeometry: List[Geometry] = None
    modified: Literal = None
    isSpatialCoverageOf: List[Thing] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasGeometry:
            for hasGeometry in self.hasGeometry:
                g.add((self.uriRef, CLV["hasGeometry"], hasGeometry.uriRef))

        if self.modified:
            g.add((self.uriRef, TI["modified"], self.modified))

        if self.isSpatialCoverageOf:
            for isSpatialCoverageOf in self.isSpatialCoverageOf:
                g.add(
                    (self.uriRef, CLV["isSpatialCoverageOf"], isSpatialCoverageOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .Channel import Channel

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class OtherElectronicChannel(Channel):
    __type__ = CPSV["OtherElectronicChannel"]

    accessReference: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.accessReference:
            g.add((self.uriRef, CPSV["accessReference"], self.accessReference))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .TemporalEntity import TemporalEntity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .TimeInterval import TimeInterval


class TimeInstant(TemporalEntity):
    __type__ = TI["TimeInstant"]

    fallsInside: List[TimeInterval] = []
    date: Literal = None
    month: Literal = None
    year: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for fallsInside in self.fallsInside:
            g.add((self.uriRef, TI["fallsInside"],
                  fallsInside.uriRef))

        if self.date:
            g.add((self.uriRef, TI["date"], self.date))

        if self.month:
            g.add((self.uriRef, TI["month"], self.month))

        if self.year:
            g.add((self.uriRef, TI["year"], self.year))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .OSDFeature import OSDFeature

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..pot.Offer import Offer
    from .Accommodation import Accommodation
    from .OfferedServiceDescription import OfferedServiceDescription


class AccommodationRoom(OSDFeature):
    __type__ = ACCO["AccommodationRoom"]

    hasOfferedServiceDescription: List[OfferedServiceDescription] = None
    hasOffer: List[Offer] = None
    isAccommodationRoomOf: Accommodation = None
    roomName: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasOfferedServiceDescription:
            for hasOfferedServiceDescription in self.hasOfferedServiceDescription:
                g.add(
                    (self.uriRef, ACCO["hasOfferedServiceDescription"], hasOfferedServiceDescription.uriRef))

        if self.hasOffer:
            for hasOffer in self.hasOffer:
                g.add((self.uriRef, POT["hasOffer"], hasOffer.uriRef))

        if self.isAccommodationRoomOf:
            g.add((self.uriRef, ACCO["isAccommodationRoomOf"],
                  self.isAccommodationRoomOf.uriRef))

        if self.roomName:
            g.add((self.uriRef, ACCO["roomName"], self.roomName))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..sm.WebSite import WebSite
    from .CollectionCulEnt import CollectionCulEnt
    from .CulturalInstituteOrSite import CulturalInstituteOrSite


class Catalogue(Object):
    __type__ = CIS["Catalogue"]

    describesCulturalEntity: List[CollectionCulEnt] = None
    isCatalogueOf: List[CulturalInstituteOrSite] = None
    hasWebSite: List[WebSite] = None
    name: List[Literal] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.describesCulturalEntity:
            for describesCulturalEntity in self.describesCulturalEntity:
                g.add(
                    (self.uriRef, CIS["describesCulturalEntity"], describesCulturalEntity.uriRef))

        if self.isCatalogueOf:
            for isCatalogueOf in self.isCatalogueOf:
                g.add(
                    (self.uriRef, CIS["isCatalogueOf"], isCatalogueOf.uriRef))

        if self.hasWebSite:
            for hasWebSite in self.hasWebSite:
                g.add((self.uriRef, SM["hasWebSite"], hasWebSite.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.System import System
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .FormalFramework import FormalFramework
    from .Requirement import Requirement
    from .Service import Service


class Rule(System):
    __type__ = CPSV["Rule"]

    implementsFF: List[FormalFramework] = None
    isFollowedByService: List[Service] = None
    specifiesReq: List[Requirement] = None
    description: List[Literal] = None
    name: List[Literal] = None
    referenceDoc: List[Literal] = None
    identifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.implementsFF:
            for implementsFF in self.implementsFF:
                g.add((self.uriRef, CPSV["implementsFF"], implementsFF.uriRef))

        if self.isFollowedByService:
            for isFollowedByService in self.isFollowedByService:
                g.add(
                    (self.uriRef, CPSV["isFollowedByService"], isFollowedByService.uriRef))

        if self.specifiesReq:
            for specifiesReq in self.specifiesReq:
                g.add((self.uriRef, CPSV["specifiesReq"], specifiesReq.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.referenceDoc:
            for referenceDoc in self.referenceDoc:
                g.add((self.uriRef, CPSV["referenceDoc"], referenceDoc))

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..clv.Feature import Feature
from ..ns import *
from ..poi.PointOfInterest import PointOfInterest

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..clv.Address import Address
    from ..clv.Feature import Feature
    from ..sm.OnlineContactPoint import OnlineContactPoint
    from .CulturalEvent import CulturalEvent
    from .CulturalInstituteOrSite import CulturalInstituteOrSite
    from .SiteDescription import SiteDescription


class Site(Feature, PointOfInterest):
    __type__ = CIS["Site"]

    isSiteOf: List[CulturalInstituteOrSite] = None
    hasSiteDescription: List[SiteDescription] = None
    hostsCulturalEvent: List[CulturalEvent] = None
    siteAddress: List[CulturalInstituteOrSite] = None
    isSiteOf: List[Address] = None
    hasSpatialCoverage: List[Feature] = None
    hasOnlineContactPoint: List[OnlineContactPoint] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isSiteOf:
            for isSiteOf in self.isSiteOf:
                g.add((self.uriRef, CIS["isSiteOf"], isSiteOf.uriRef))

        if self.hasSiteDescription:
            for hasSiteDescription in self.hasSiteDescription:
                g.add(
                    (self.uriRef, CIS["hasSiteDescription"], hasSiteDescription.uriRef))

        if self.hostsCulturalEvent:
            for hostsCulturalEvent in self.hostsCulturalEvent:
                g.add(
                    (self.uriRef, CIS["hostsCulturalEvent"], hostsCulturalEvent.uriRef))

        if self.siteAddress:
            for siteAddress in self.siteAddress:
                g.add((self.uriRef, CIS["siteAddress"], siteAddress.uriRef))

        if self.isSiteOf:
            for isSiteOf in self.isSiteOf:
                g.add((self.uriRef, CIS["isSiteOf"], isSiteOf.uriRef))

        if self.hasSpatialCoverage:
            for hasSpatialCoverage in self.hasSpatialCoverage:
                g.add(
                    (self.uriRef, CLV["hasSpatialCoverage"], hasSpatialCoverage.uriRef))

        if self.hasOnlineContactPoint:
            for hasOnlineContactPoint in self.hasOnlineContactPoint:
                g.add(
                    (self.uriRef, SM["hasOnlineContactPoint"], hasOnlineContactPoint.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Concept import Concept
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .SupportService import SupportService


class ServiceType(Concept):
    __type__ = PATHS["ServiceType"]

    isServiceTypeOf: List[SupportService] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isServiceTypeOf:
            for isServiceTypeOf in self.isServiceTypeOf:
                g.add(
                    (self.uriRef, PATHS["isServiceTypeOf"], isServiceTypeOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Agent import Agent
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..clv.Address import Address
    from ..l0.Location import Location
    from .Person import Person
    from .PersonTitle import PersonTitle
    from .ResidenceInTime import ResidenceInTime
    from .Sex import Sex


class Person(Agent):
    __type__ = CPV["Person"]

    hasAddress: List[Address] = None
    hasParentalRelationshipWith: List[Person] = None
    isChildOf: List[Person] = None
    isConsortOf: List[Person] = None
    isGrandChildOf: List[Person] = None
    isGrandFatherOf: List[Person] = None
    isNephewOf: List[Person] = None
    isParentOf: List[Person] = None
    isUncleOf: List[Person] = None
    hasPersonTitle: List[PersonTitle] = None
    hasRelationshipWith: List[Person] = None
    knows: List[Person] = None
    hasResidenceInTime: List[ResidenceInTime] = None
    residentIn: List[Address] = None
    hasBirthPlace: Location = None
    hasCitizenship: List[Location] = None
    hasSex: Sex = None
    dateOfBirth: Literal = None
    personID: Literal = None
    altName: Literal = None
    familyName: Literal = None
    givenName: Literal = None
    taxCode: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAddress:
            for hasAddress in self.hasAddress:
                g.add((self.uriRef, CLV["hasAddress"], hasAddress.uriRef))

        if self.hasParentalRelationshipWith:
            for hasParentalRelationshipWith in self.hasParentalRelationshipWith:
                g.add(
                    (self.uriRef, CPV["hasParentalRelationshipWith"], hasParentalRelationshipWith.uriRef))

        if self.isChildOf:
            for isChildOf in self.isChildOf:
                g.add((self.uriRef, CPV["isChildOf"], isChildOf.uriRef))

        if self.isConsortOf:
            for isConsortOf in self.isConsortOf:
                g.add((self.uriRef, CPV["isConsortOf"], isConsortOf.uriRef))

        if self.isGrandChildOf:
            for isGrandChildOf in self.isGrandChildOf:
                g.add(
                    (self.uriRef, CPV["isGrandChildOf"], isGrandChildOf.uriRef))

        if self.isGrandFatherOf:
            for isGrandFatherOf in self.isGrandFatherOf:
                g.add(
                    (self.uriRef, CPV["isGrandFatherOf"], isGrandFatherOf.uriRef))

        if self.isNephewOf:
            for isNephewOf in self.isNephewOf:
                g.add((self.uriRef, CPV["isNephewOf"], isNephewOf.uriRef))

        if self.isParentOf:
            for isParentOf in self.isParentOf:
                g.add((self.uriRef, CPV["isParentOf"], isParentOf.uriRef))

        if self.isUncleOf:
            for isUncleOf in self.isUncleOf:
                g.add((self.uriRef, CPV["isUncleOf"], isUncleOf.uriRef))

        if self.hasPersonTitle:
            for hasPersonTitle in self.hasPersonTitle:
                g.add(
                    (self.uriRef, CPV["hasPersonTitle"], hasPersonTitle.uriRef))

        if self.hasRelationshipWith:
            for hasRelationshipWith in self.hasRelationshipWith:
                g.add(
                    (self.uriRef, CPV["hasRelationshipWith"], hasRelationshipWith.uriRef))

        if self.knows:
            for knows in self.knows:
                g.add((self.uriRef, CPV["knows"], knows.uriRef))

        if self.hasResidenceInTime:
            for hasResidenceInTime in self.hasResidenceInTime:
                g.add(
                    (self.uriRef, CPV["hasResidenceInTime"], hasResidenceInTime.uriRef))

        if self.residentIn:
            for residentIn in self.residentIn:
                g.add((self.uriRef, CPV["residentIn"], residentIn.uriRef))

        if self.hasCitizenship:
            for hasCitizenship in self.hasCitizenship:
                g.add(
                    (self.uriRef, CPV["hasCitizenship"], hasCitizenship.uriRef))

        if self.hasBirthPlace:
            g.add((self.uriRef, CPV["hasBirthPlace"], self.hasBirthPlace.uriRef))

        if self.dateOfBirth:
            g.add((self.uriRef, CPV["dateOfBirth"], self.dateOfBirth))

        if self.personID:
            g.add((self.uriRef, CPV["personID"], self.personID))

        if self.altName:
            g.add((self.uriRef, CPV["altName"], self.altName))

        if self.familyName:
            g.add((self.uriRef, CPV["familyName"], self.familyName))

        if self.givenName:
            g.add((self.uriRef, CPV["givenName"], self.givenName))

        if self.taxCode:
            g.add((self.uriRef, CPV["taxCode"], self.taxCode))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Document import Document

if TYPE_CHECKING:
    from rdflib import Graph

    from ..l0.Agent import Agent
    from ..ro.TimeIndexedRole import TimeIndexedRole
    from .AmendmentDocument import AmendmentDocument
    from .CommonProcurementVocabulary import CommonProcurementVocabulary
    from .EconomicSummary import EconomicSummary
    from .FrameworkAgreement import FrameworkAgreement
    from .Resolution import Resolution
    from .Tender import Tender


class Contract(Document):
    __type__ = PUBC["Contract"]

    hasCPV: List[CommonProcurementVocabulary] = None
    refersToTender: List[Tender] = None
    hasChangeDocument: List[AmendmentDocument] = None
    hasContractualResolution: List[Resolution] = None
    hasEconomicSummary: List[EconomicSummary] = None
    winner: List[Agent] = None
    holdsRoleInTime: List[TimeIndexedRole] = None
    hasFrameworkAgreement: FrameworkAgreement = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCPV:
            for hasCPV in self.hasCPV:
                g.add((self.uriRef, PUBC["hasCPV"], hasCPV.uriRef))

        if self.refersToTender:
            for refersToTender in self.refersToTender:
                g.add(
                    (self.uriRef, PUBC["refersToTender"], refersToTender.uriRef))

        if self.hasChangeDocument:
            for hasChangeDocument in self.hasChangeDocument:
                g.add(
                    (self.uriRef, PUBC["hasChangeDocument"], hasChangeDocument.uriRef))

        if self.hasContractualResolution:
            for hasContractualResolution in self.hasContractualResolution:
                g.add(
                    (self.uriRef, PUBC["hasContractualResolution"], hasContractualResolution.uriRef))

        if self.hasEconomicSummary:
            for hasEconomicSummary in self.hasEconomicSummary:
                g.add(
                    (self.uriRef, PUBC["hasEconomicSummary"], hasEconomicSummary.uriRef))

        if self.winner:
            for winner in self.winner:
                g.add((self.uriRef, PUBC["winner"], winner.uriRef))

        if self.holdsRoleInTime:
            for holdsRoleInTime in self.holdsRoleInTime:
                g.add(
                    (self.uriRef, RO["holdsRoleInTime"], holdsRoleInTime.uriRef))

        if self.hasFrameworkAgreement:
            g.add((self.uriRef, PUBC["hasFrameworkAgreement"],
                  self.hasFrameworkAgreement.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.Activity import Activity
    from ..mu.Value import Value


class Correction(Characteristic):
    __type__ = INDIC["Correction"]

    isAppliedTo: List[Activity] = None
    hasCorrectionValue: Value = None
    doneAt: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isAppliedTo:
            for isAppliedTo in self.isAppliedTo:
                g.add((self.uriRef, INDIC["isAppliedTo"], isAppliedTo.uriRef))

        if self.hasCorrectionValue:
            g.add(
                (self.uriRef, INDIC["hasCorrectionValue"], self.hasCorrectionValue.uriRef))

        if self.doneAt:
            g.add((self.uriRef, INDIC["doneAt"], self.doneAt))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from rdflib import Graph

from ..l0.Location import Location
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..ti.TimeInterval import TimeInterval
    from .Identifier import Identifier


class SpatialObject(Location):
    __type__ = CLV["SpatialObject"]

    hasIdentifier: List[Identifier] = None
    hasSOValidity: List[TimeInterval] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasIdentifier:
            for hasIdentifier in self.hasIdentifier:
                g.add(
                    (self.uriRef, CLV["hasIdentifier"], hasIdentifier.uriRef))

        if self.hasSOValidity:
            for hasSOValidity in self.hasSOValidity:
                g.add(
                    (self.uriRef, CLV["hasSOValidity"], hasSOValidity.uriRef))



from .Card import Card
from .Currency import Currency
from .Offer import Offer
from .PriceSpecification import PriceSpecification
from .Ticket import Ticket
from .UserType import UserType
from .Validity import Validity



from __future__ import annotations

from typing import TYPE_CHECKING, List, Union

from ..l0.EventOrSituation import EventOrSituation
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..mu.Value import Value
    from ..ti.TimeInterval import TimeInterval


class Validity(EventOrSituation):
    __type__ = POT["Validity"]

    hasDuration: List[Union[Value, TimeInterval]] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasDuration:
            for hasDuration in self.hasDuration:
                g.add((self.uriRef, TI["hasDuration"], hasDuration.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .PointOfInterest import PointOfInterest

if TYPE_CHECKING:
    from rdflib import Graph


class MultiplePointOfInterest(PointOfInterest):
    __type__ = POI["MultiplePointOfInterest"]

    includesPOI: List[PointOfInterest] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.includesPOI:
            for includesPOI in self.includesPOI:
                g.add((self.uriRef, POI["includesPOI"], includesPOI.uriRef))



from __future__ import annotations

from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *


class TransparencyActivityTypology(Characteristic):
    __type__ = TRANSP["TransparencyActivityTypology"]


class TransparencyArchiveActivity(TransparencyActivityTypology):
    def __init__(self):
        self.uriRef = URIRef(TRANSP["TransparencyArchiveActivity"])


class TransparencyPublicationActivity(TransparencyActivityTypology):
    def __init__(self):
        self.uriRef = URIRef(TRANSP["TransparencyPublicationActivity"])


class TransparencyUpdateActivity(TransparencyActivityTypology):
    def __init__(self):
        self.uriRef = URIRef(TRANSP["TransparencyUpdateActivity"])



from .Authentication import Authentication
from .BusinessEvent import BusinessEvent
from .Channel import Channel
from .ChannelType import ChannelType
from .Cost import Cost
from .EmailChannel import EmailChannel
from .EventType import EventType
from .FixedCost import FixedCost
from .FormalFramework import FormalFramework
from .Input import Input
from .InteractivityLevel import InteractivityLevel
from .InternalOrganizationService import InternalOrganizationService
from .InterOrganizationService import InterOrganizationService
from .LifeEvent import LifeEvent
from .OfflineChannel import OfflineChannel
from .OtherElectronicChannel import OtherElectronicChannel
from .Output import Output
from .PhoneChannel import PhoneChannel
from .PublicService import PublicService
from .Requirement import Requirement
from .RoleOnService import RoleOnService
from .Rule import Rule
from .Service import Service
from .ServiceInputOutputType import ServiceInputOutputType
from .ServiceProcessingTime import ServiceProcessingTime
from .ServiceSector import ServiceSector
from .ServiceStatus import ServiceStatus
from .ServiceTheme import ServiceTheme
from .StandardTech import StandardTech
from .VariableCost import VariableCost
from .WebSiteChannel import WebSiteChannel


from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.EventOrSituation import EventOrSituation
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..l0.Agent import Agent
    from ..l0.Entity import Entity
    from ..ti.TemporalEntity import TemporalEntity
    from .Role import Role


class TimeIndexedRole(EventOrSituation):
    __type__ = RO["TimeIndexedRole"]

    forEntity: List[Entity] = None
    isRoleInTimeOf: List[Agent] = None
    withRole: List[Role] = None
    hasTemporalEntity: List[TemporalEntity] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.forEntity:
            for forEntity in self.forEntity:
                g.add((self.uriRef, RO["forEntity"], forEntity.uriRef))

        if self.isRoleInTimeOf:
            for isRoleInTimeOf in self.isRoleInTimeOf:
                g.add((self.uriRef, RO["isRoleInTimeOf"],
                      isRoleInTimeOf.uriRef))

        if self.withRole:
            for withRole in self.withRole:
                g.add((self.uriRef, RO["withRole"], withRole.uriRef))

        if self.hasTemporalEntity:
            for hasTemporalEntity in self.hasTemporalEntity:
                g.add(
                    (self.uriRef, TI["hasTemporalEntity"], hasTemporalEntity.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .Collection import Collection

if TYPE_CHECKING:
    from rdflib import Graph

    from .Entity import Entity


class Sequence(Collection):
    __type__ = L0["Sequence"]

    hasFirstMember: Entity = None
    hasLastMember: Entity = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasFirstMember:
            g.add((self.uriRef, L0["hasFirstMember"],
                  self.hasFirstMember.uriRef))

        if self.hasLastMember:
            g.add((self.uriRef, L0["hasLastMember"],
                  self.hasLastMember.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List, Union

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .CulturalEntity import CulturalEntity
    from .CulturalEvent import CulturalEvent
    from .Site import Site


class CreativeWork(Object):
    __type__ = CIS["CreativeWork"]

    isAbout: List[Union[CulturalEntity, CulturalEvent, Site]] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isAbout:
            for isAbout in self.isAbout:
                g.add((self.uriRef, CIS["isAbout"], isAbout.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *
from .CulturalEntity import CulturalEntity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Site import Site


class CulturalHeritageObject(CulturalEntity, Object):
    __type__ = CIS["CulturalHeritageObject"]

    isInSite: List[Site] = None
    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isInSite:
            for isInSite in self.isInSite:
                g.add((self.uriRef, CIS["isInSite"], isInSite.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .AccessCondition import AccessCondition

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..ti.DayOfWeek import DayOfWeek
    from ..ti.TimeInterval import TimeInterval


class TemporaryClosure(AccessCondition):
    __type__ = ACOND["TemporaryClosure"]

    atTime: List[TimeInterval] = None
    hasDayOfWeek: List[DayOfWeek] = None
    reasonClosure: List[Literal] = None
    closes: List[Literal] = None
    opens: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.atTime:
            for atTime in self.atTime:
                g.add((self.uriRef, TI["atTime"], atTime.uriRef))

        if self.hasDayOfWeek:
            for hasDayOfWeek in self.hasDayOfWeek:
                g.add((self.uriRef, TI["hasDayOfWeek"], hasDayOfWeek.uriRef))

        if self.reasonClosure:
            for reasonClosure in self.reasonClosure:
                g.add((self.uriRef, ACOND["reasonClosure"], reasonClosure))

        if self.closes:
            for closes in self.closes:
                g.add((self.uriRef, ACOND["closes"], closes))

        if self.opens:
            for opens in self.opens:
                g.add((self.uriRef, ACOND["opens"], opens))



from .Format import Format
from .TransparencyActivity import TransparencyActivity
from .TransparencyActivityTypology import TransparencyActivityTypology
from .TransparencyArchiveActivity import TransparencyArchiveActivity
from .TransparencyDataTypology import TransparencyDataTypology
from .TransparencyObligation import TransparencyObligation
from .TransparencyObligationStatus import TransparencyObligationStatus
from .TransparencyPublicationActivity import TransparencyPublicationActivity
from .TransparencyResource import TransparencyResource
from .TransparencySubject import TransparencySubject
from .TransparencyUpdateActivity import TransparencyUpdateActivity
from .UpdateFrequency import UpdateFrequency


from __future__ import annotations

from typing import TYPE_CHECKING, List, Union

from ..l0.Collection import Collection
from ..ns import *
from .CulturalEntity import CulturalEntity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..ti.TimeInterval import TimeInterval
    from .Catalogue import Catalogue
    from .CollectionCulEnt import CollectionCulEnt
    from .CulturalHeritageObject import CulturalHeritageObject


class CollectionCulEnt(CulturalEntity, Collection):
    __type__ = CIS["CollectionCulEnt"]

    hasMemberColCultEnt: List[Union[CollectionCulEnt,
                                    CulturalHeritageObject]] = None
    isDescribedBy: List[Catalogue] = None
    atTime: List[TimeInterval] = None
    name: List[Literal] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasMemberColCultEnt:
            for hasMemberColCultEnt in self.hasMemberColCultEnt:
                g.add(
                    (self.uriRef, CIS["hasMemberColCultEnt"], hasMemberColCultEnt.uriRef))

        if self.isDescribedBy:
            for isDescribedBy in self.isDescribedBy:
                g.add(
                    (self.uriRef, CIS["isDescribedBy"], isDescribedBy.uriRef))

        if self.atTime:
            for atTime in self.atTime:
                g.add((self.uriRef, TI["atTime"], atTime.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Topic import Topic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .PointOfInterest import PointOfInterest


class PointOfInterestCategory(Topic):
    __type__ = POI["PointOfInterestCategory"]

    POIcategoryName: List[Literal] = None
    isPOICategoryFor: List[PointOfInterest] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.POIcategoryName:
            for POIcategoryName in self.POIcategoryName:
                g.add((self.uriRef, POI["POIcategoryName"], POIcategoryName))

        if self.isPOICategoryFor:
            for isPOICategoryFor in self.isPOICategoryFor:
                g.add(
                    (self.uriRef, POI["isPOICategoryFor"], isPOICategoryFor.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..mu.Value import Value

if TYPE_CHECKING:
    from rdflib import Graph

    from .MeasurementQuality import MeasurementQuality


class MeasurementQualityValue(Value):
    __type__ = IOT["MeasurementQualityValue"]

    isMeasurementQualityValueOf: List[MeasurementQuality] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isMeasurementQualityValueOf:
            for isMeasurementQualityValueOf in self.isMeasurementQualityValueOf:
                g.add(
                    (self.uriRef, IOT["isMeasurementQualityValueOf"], isMeasurementQualityValueOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..Thing import Thing
    from ..ti.Duration import Duration
    from .Route import Route


class TripPlan(Description):
    __type__ = ROUTE["TripPlan"]

    hasRoute: List[Route] = None
    hasSubTripPlan: List[TripPlan] = None
    hasSuperTripPlan: List[TripPlan] = None
    hasEstimatedDuration: Duration = None
    isTripPlanOf: Thing = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasRoute:
            for hasRoute in self.hasRoute:
                g.add((self.uriRef, ROUTE["hasRoute"], hasRoute.uriRef))

        if self.hasSubTripPlan:
            for hasSubTripPlan in self.hasSubTripPlan:
                g.add(
                    (self.uriRef, ROUTE["hasSubTripPlan"], hasSubTripPlan.uriRef))

        if self.hasSuperTripPlan:
            for hasSuperTripPlan in self.hasSuperTripPlan:
                g.add(
                    (self.uriRef, ROUTE["hasSuperTripPlan"], hasSuperTripPlan.uriRef))

        if self.hasEstimatedDuration:
            g.add(
                (self.uriRef, ROUTE["hasEstimatedDuration"], self.hasEstimatedDuration.uriRef))

        if self.isTripPlanOf:
            g.add((self.uriRef, ROUTE["isTripPlanOf"],
                  self.isTripPlanOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Service import Service

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class InternalOrganizationService(Service):
    __type__ = CPSV["InternalOrganizationService"]

    additionalNoteForService: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.additionalNoteForService:
            for additionalNoteForService in self.additionalNoteForService:
                g.add(
                    (self.uriRef, CPSV["additionalNoteForService"], additionalNoteForService))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from rdflib import URIRef

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .PathPlan import PathPlan


class TravellingMethod(Description):
    __type__ = PATHS["TravellingMethod"]

    isTravellingMethodOf: List[PathPlan] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isTravellingMethodOf:
            for isTravellingMethodOf in self.isTravellingMethodOf:
                g.add(
                    (self.uriRef, PATHS["isTravellingMethodOf"], isTravellingMethodOf.uriRef))


class Cycling(TravellingMethod):
    def __init__(self):
        self.uriRef = URIRef(PATHS["Cycling"])


class Horseback(TravellingMethod):
    def __init__(self):
        self.uriRef = URIRef(PATHS["Horseback"])


class Walking(TravellingMethod):
    def __init__(self):
        self.uriRef = URIRef(PATHS["Walking"])



from .ArchaeologicalArea import ArchaeologicalArea
from .ArchaeologicalPark import ArchaeologicalPark
from .Attribute import Attribute
from .AudioObject import AudioObject
from .Catalogue import Catalogue
from .Cinema import Cinema
from .CISNameInTime import CISNameInTime
from .CISService import CISService
from .CISType import CISType
from .ClericalAdministrativeArea import ClericalAdministrativeArea
from .CollectionCulEnt import CollectionCulEnt
from .CreativeWork import CreativeWork
from .CultResearchCenter import CultResearchCenter
from .CulturalEntity import CulturalEntity
from .CulturalEvent import CulturalEvent
from .CulturalHeritageObject import CulturalHeritageObject
from .CulturalInstituteOrSite import CulturalInstituteOrSite
from .CulturalLandscapeAsset import CulturalLandscapeAsset
from .CulturalProject import CulturalProject
from .Equipment import Equipment
from .HolderOfArchive import HolderOfArchive
from .ImageObject import ImageObject
from .Library import Library
from .MonumentalArea import MonumentalArea
from .Museum import Museum
from .NewsArticle import NewsArticle
from .Site import Site
from .SiteDescription import SiteDescription
from .SubjectDiscipline import SubjectDiscipline
from .Theatre import Theatre
from .VideoObject import VideoObject


from .Audience import Audience
from .Event import Event
from .EventFormat import EventFormat
from .Playbill import Playbill
from .PublicEvent import PublicEvent
from .PublicEventTypology import PublicEventTypology



from __future__ import annotations

from ..l0.Characteristic import Characteristic
from ..ns import *


class TransparencyDataTypology(Characteristic):
    __type__ = TRANSP["TransparencyDataTypology"]



from .AcademicDiscipline import AcademicDiscipline
from .AcademicRecruitementField import AcademicRecruitementField
from .Area import Area
from .HERClassification import HERClassification
from .MacroSector import MacroSector
from .ScientificDisciplinarySector import ScientificDisciplinarySector



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .AddressComponent import AddressComponent

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class StreetToponym(AddressComponent):
    __type__ = CLV["StreetToponym"]

    officialStreetName: List[Literal] = None
    toponymQualifier: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.officialStreetName:
            for officialStreetName in self.officialStreetName:
                g.add(
                    (self.uriRef, CLV["officialStreetName"], officialStreetName))

        if self.toponymQualifier:
            for toponymQualifier in self.toponymQualifier:
                g.add((self.uriRef, CLV["toponymQualifier"], toponymQualifier))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .UserAccount import UserAccount


class Post(Object):
    __type__ = SM["Post"]

    hasCreator: UserAccount = None
    postContent: Literal = None
    hasReply: List[Post] = None
    isReplyOf: List[Post] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCreator:
            g.add((self.uriRef, SM["hasCreator"], self.hasCreator.uriRef))

        if self.postContent:
            g.add((self.uriRef, SM["postContent"], self.postContent))

        if self.hasReply:
            for hasReply in self.hasReply:
                g.add((self.uriRef, SM["hasReply"], hasReply.uriRef))

        if self.isReplyOf:
            for isReplyOf in self.isReplyOf:
                g.add((self.uriRef, SM["isReplyOf"], isReplyOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Address import Address


class InternalAccess(Characteristic):
    __type__ = CLV["InternalAccess"]

    refersToExternalAccess: List[Address] = None
    staircase: List[Literal] = None
    flatNumber: Literal = None
    building: Literal = None
    exponent: Literal = None
    floor: Literal = None
    yard: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.refersToExternalAccess:
            for refersToExternalAccess in self.refersToExternalAccess:
                g.add(
                    (self.uriRef, CLV["refersToExternalAccess"], refersToExternalAccess.uriRef))

        if self.staircase:
            for staircase in self.staircase:
                g.add((self.uriRef, CLV["staircase"], staircase))

        if self.flatNumber:
            g.add((self.uriRef, CLV["flatNumber"], self.flatNumber))

        if self.building:
            g.add((self.uriRef, CLV["building"], self.building))

        if self.exponent:
            g.add((self.uriRef, CLV["exponent"], self.exponent))

        if self.floor:
            g.add((self.uriRef, CLV["floor"], self.floor))

        if self.yard:
            g.add((self.uriRef, CLV["yard"], self.yard))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0 import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..cov.Organization import Organization


class Identifier(Characteristic):
    __type__ = CLV["Identifier"]

    issuedBy: List[Organization] = None
    identifier: Literal = None
    identifierType: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.issuedBy:
            for issuedBy in self.issuedBy:
                g.add((self.uriRef, CLV["issuedBy"], issuedBy.uriRef))

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))

        if self.identifierType:
            g.add((self.uriRef, CLV["identifierType"], self.identifierType))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Path import Path
    from .Pathway import Pathway
    from .Paving import Paving


class QuantifiedPathwayPaving(Object):
    __type__ = PATHS["QuantifiedPathwayPaving"]

    isQuantifiedPathwayPavingOf: List[Path] = None
    forPathway: Pathway = None
    withPaving: Paving = None
    maxPercentage: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isQuantifiedPathwayPavingOf:
            for isQuantifiedPathwayPavingOf in self.isQuantifiedPathwayPavingOf:
                g.add(
                    (self.uriRef, PATHS["isQuantifiedPathwayPavingOf"], isQuantifiedPathwayPavingOf.uriRef))

        if self.forPathway:
            g.add((self.uriRef, PATHS["forPathway"], self.forPathway.uriRef))

        if self.withPaving:
            g.add((self.uriRef, PATHS["withPaving"], self.withPaving.uriRef))

        if self.maxPercentage:
            g.add((self.uriRef, MU["maxPercentage"], self.maxPercentage))



from .AlivePerson import AlivePerson
from .BornDead import BornDead
from .Dead import Dead
from .EducationLevel import EducationLevel
from .Family import Family
from .FamilySheetHolder import FamilySheetHolder
from .Female import Female
from .ForeignCitizen import ForeignCitizen
from .ItalianCitizen import ItalianCitizen
from .Male import Male
from .NotResident import NotResident
from .ParentalRelationshipType import ParentalRelationshipType
from .Person import Person
from .PersonTitle import PersonTitle
from .RegisteredFamily import RegisteredFamily
from .ResidenceInTime import ResidenceInTime
from .Resident import Resident
from .Sex import Sex
from .Stateless import Stateless


from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .PriceSpecification import PriceSpecification
    from .Ticket import Ticket
    from .UserType import UserType
    from .Validity import Validity


class Offer(Description):
    __type__ = POT["Currency"]

    hasPriceSpecification: List[PriceSpecification] = None
    hasValidity: List[Validity] = None
    includes: List[Ticket] = None
    description: List[Literal] = None
    hasEligibleUser: List[UserType] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasPriceSpecification:
            for hasPriceSpecification in self.hasPriceSpecification:
                g.add(
                    (self.uriRef, POT["hasPriceSpecification"], hasPriceSpecification.uriRef))

        if self.hasValidity:
            for hasValidity in self.hasValidity:
                g.add((self.uriRef, POT["hasValidity"], hasValidity.uriRef))

        if self.includes:
            for includes in self.includes:
                g.add((self.uriRef, POT["includes"], includes.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.hasEligibleUser:
            for hasEligibleUser in self.hasEligibleUser:
                g.add(
                    (self.uriRef, POT["hasEligibleUser"], hasEligibleUser.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Feature import Feature

if TYPE_CHECKING:
    from rdflib import Graph


class AddressComponent(Feature):
    __type__ = CLV["AddressComponent"]

    situatedWithin: List[AddressComponent] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.situatedWithin:
            for situatedWithin in self.situatedWithin:
                g.add(
                    (self.uriRef, CLV["situatedWithin"], situatedWithin.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..poi.PointOfInterest import PointOfInterest

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..accesscondition.AccessCondition import AccessCondition
    from ..pot.Offer import Offer
    from ..sm.OnlineContactPoint import OnlineContactPoint
    from ..sm.Review import Review
    from .CarParkTypology import CarParkTypology


class CarPark(PointOfInterest):
    __type__ = PARK["CarPark"]

    hasOffer: List[Offer] = None
    hasOnlineContactPoint: List[OnlineContactPoint] = None
    hasReview: List[Review] = None
    hasCarParkTypology: List[CarParkTypology] = None
    hasAccessCondition: List[AccessCondition] = None
    carParkName: List[Literal] = None
    carParkDescription: List[Literal] = None
    numSpacesForDisabled: Literal = None
    numPayingParkingSpaces: Literal = None
    numAvailableParkingSpaces: Literal = None
    numSoldCarParkSpaces: Literal = None
    totalNumCarParkSpaces: Literal = None
    carParkID: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasOffer:
            for hasOffer in self.hasOffer:
                g.add((self.uriRef, POT["hasOffer"], hasOffer.uriRef))

        if self.hasOnlineContactPoint:
            for hasOnlineContactPoint in self.hasOnlineContactPoint:
                g.add(
                    (self.uriRef, SM["hasOnlineContactPoint"], hasOnlineContactPoint.uriRef))

        if self.hasReview:
            for hasReview in self.hasReview:
                g.add((self.uriRef, SM["hasReview"], hasReview.uriRef))

        if self.hasCarParkTypology:
            for hasCarParkTypology in self.hasCarParkTypology:
                g.add(
                    (self.uriRef, PARK["hasCarParkTypology"], hasCarParkTypology.uriRef))

        if self.hasAccessCondition:
            for hasAccessCondition in self.hasAccessCondition:
                g.add(
                    (self.uriRef, ACOND["hasAccessCondition"], hasAccessCondition.uriRef))

        if self.carParkName:
            for carParkName in self.carParkName:
                g.add((self.uriRef, PARK["carParkName"], carParkName))

        if self.carParkDescription:
            for carParkDescription in self.carParkDescription:
                g.add(
                    (self.uriRef, PARK["carParkDescription"], carParkDescription))

        if self.numSpacesForDisabled:
            g.add(
                (self.uriRef, PARK["numSpacesForDisabled"], self.numSpacesForDisabled))

        if self.numPayingParkingSpaces:
            g.add(
                (self.uriRef, PARK["numPayingParkingSpaces"], self.numPayingParkingSpaces))

        if self.numAvailableParkingSpaces:
            g.add(
                (self.uriRef, PARK["numAvailableParkingSpaces"], self.numAvailableParkingSpaces))

        if self.numSoldCarParkSpaces:
            g.add(
                (self.uriRef, PARK["numSoldCarParkSpaces"], self.numSoldCarParkSpaces))

        if self.totalNumCarParkSpaces:
            g.add(
                (self.uriRef, PARK["totalNumCarParkSpaces"], self.totalNumCarParkSpaces))

        if self.carParkID:
            g.add((self.uriRef, PARK["carParkID"], self.carParkID))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..poi.PointOfInterest import PointOfInterest

if TYPE_CHECKING:
    from rdflib import Graph

    from .PathStage import PathStage


class Restaurant(PointOfInterest):
    __type__ = PATHS["Restaurant"]

    isNearbyRestaurantOf: List[PathStage] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isNearbyRestaurantOf:
            for isNearbyRestaurantOf in self.isNearbyRestaurantOf:
                g.add(
                    (self.uriRef, PATHS["isNearbyRestaurantOf"], isNearbyRestaurantOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Topic import Topic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .CarPark import CarPark


class CarParkTypology(Topic):
    __type__ = PARK["CarParkTypology"]

    isCarParkTypologyOf: List[CarPark] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isCarParkTypologyOf:
            for isCarParkTypologyOf in self.isCarParkTypologyOf:
                g.add(
                    (self.uriRef, PARK["isCarParkTypologyOf"], isCarParkTypologyOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Topic import Topic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .Accommodation import Accommodation


class AccommodationTypology(Topic):
    __type__ = ACCO["AccommodationTypology"]

    isAccommodationTypologyOf: List[Accommodation] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isAccommodationTypologyOf:
            for isAccommodationTypologyOf in self.isAccommodationTypologyOf:
                g.add(
                    (self.uriRef, ACCO["isAccommodationTypologyOf"], isAccommodationTypologyOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Event import Event

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..accesscondition.AccessCondition import AccessCondition
    from ..poi.PointOfInterest import PointOfInterest
    from ..pot.Offer import Offer
    from ..ro.TimeIndexedRole import TimeIndexedRole
    from ..sm.Image import Image
    from ..sm.OnlineContactPoint import OnlineContactPoint
    from ..sm.Review import Review
    from .Audience import Audience
    from .Playbill import Playbill
    from .PublicEventTypology import PublicEventTypology


class PublicEvent(Event):
    __type__ = COV["PublicEvent"]

    hasPublicEventTypology: List[PublicEventTypology] = None
    takesPlaceIn: List[PointOfInterest] = None
    hasRiT: List[TimeIndexedRole] = None
    hasAccessCondition: List[AccessCondition] = None
    targetAudience: List[Audience] = None
    hasOffer: List[Offer] = None
    hasImage: List[Image] = None
    hasOnlineContactPoint: List[OnlineContactPoint] = None
    hasReview: List[Review] = None
    subEventOf: List[PublicEvent] = None
    superEventOf: List[PublicEvent] = None
    hasPlaybill: Playbill = None
    eventTitle: List[Literal] = None
    description: List[Literal] = None
    eventAbstract: List[Literal] = None
    eventContentKeyword: List[Literal] = None
    shortEventTitle: List[Literal] = None
    identifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasPublicEventTypology:
            for hasPublicEventTypology in self.hasPublicEventTypology:
                g.add(
                    (self.uriRef, CPEV["hasPublicEventTypology"], hasPublicEventTypology.uriRef))

        if self.takesPlaceIn:
            for takesPlaceIn in self.takesPlaceIn:
                g.add((self.uriRef, CPEV["takesPlaceIn"], takesPlaceIn.uriRef))

        if self.hasRiT:
            for hasRiT in self.hasRiT:
                g.add((self.uriRef, RO["hasRiT"], hasRiT.uriRef))

        if self.hasAccessCondition:
            for hasAccessCondition in self.hasAccessCondition:
                g.add(
                    (self.uriRef, ACOND["hasAccessCondition"], hasAccessCondition.uriRef))

        if self.targetAudience:
            for targetAudience in self.targetAudience:
                g.add(
                    (self.uriRef, CPEV["targetAudience"], targetAudience.uriRef))

        if self.hasOffer:
            for hasOffer in self.hasOffer:
                g.add((self.uriRef, POT["hasOffer"], hasOffer.uriRef))

        if self.hasImage:
            for hasImage in self.hasImage:
                g.add((self.uriRef, SM["hasImage"], hasImage.uriRef))

        if self.hasOnlineContactPoint:
            for hasOnlineContactPoint in self.hasOnlineContactPoint:
                g.add(
                    (self.uriRef, SM["hasOnlineContactPoint"], hasOnlineContactPoint.uriRef))

        if self.hasReview:
            for hasReview in self.hasReview:
                g.add((self.uriRef, SM["hasReview"], hasReview.uriRef))

        if self.subEventOf:
            for subEventOf in self.subEventOf:
                g.add((self.uriRef, CPEV["subEventOf"], subEventOf.uriRef))

        if self.superEventOf:
            for superEventOf in self.superEventOf:
                g.add((self.uriRef, CPEV["superEventOf"], superEventOf.uriRef))

        if self.hasPlaybill:
            g.add((self.uriRef, CPEV["hasPlaybill"], self.hasPlaybill.uriRef))

        if self.eventTitle:
            for eventTitle in self.eventTitle:
                g.add((self.uriRef, CPEV["eventTitle"], eventTitle))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.eventAbstract:
            for eventAbstract in self.eventAbstract:
                g.add((self.uriRef, CPEV["eventAbstract"], eventAbstract))

        if self.eventContentKeyword:
            for eventContentKeyword in self.eventContentKeyword:
                g.add(
                    (self.uriRef, CPEV["eventContentKeyword"], eventContentKeyword))

        if self.shortEventTitle:
            for shortEventTitle in self.shortEventTitle:
                g.add((self.uriRef, CPEV["shortEventTitle"], shortEventTitle))

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Entity import Entity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .CulturalEvent import CulturalEvent


class CulturalEntity(Entity):
    __type__ = CIS["CulturalEntity"]

    isInvolvedInCulturalEvent: List[CulturalEvent] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isInvolvedInCulturalEvent:
            for isInvolvedInCulturalEvent in self.isInvolvedInCulturalEvent:
                g.add(
                    (self.uriRef, CIS["isInvolvedInCulturalEvent"], isInvolvedInCulturalEvent.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class LegalStatus(Characteristic):
    __type__ = COV["LegalStatus"]

    legalStatusCode: List[Literal] = None
    legalStatusDesc: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.legalStatusCode:
            for legalStatusCode in self.legalStatusCode:
                g.add((self.uriRef, COV["legalStatusCode"], legalStatusCode))

        if self.legalStatusDesc:
            for legalStatusDesc in self.legalStatusDesc:
                g.add((self.uriRef, COV["legalStatusDesc"], legalStatusDesc))



from typing import List

from rdflib import RDF, Graph, Literal, Namespace, URIRef
from rdflib.namespace import DC, RDF, SKOS

from .ConceptScheme import ConceptScheme


class Thing:
    _dataset: URIRef = None
    _titles: List[Literal] = []
    uriRef: URIRef = None

    def __init__(self, id: str, baseUri: Namespace, dataset: ConceptScheme = None, titles: List[Literal] = []):
        self._dataset = dataset
        self._titles = titles

        self.uriRef = URIRef(baseUri[id])

    def _addProperties(self, g: Graph):
        pass

    def addToGraph(self, g: Graph, isTopConcept=False):
        g.add((self.uriRef, RDF.type, self.__type__))

        for title in self._titles:
            g.add((self.uriRef, DC.title, title))

        if self._dataset:
            g.add((self.uriRef, SKOS.inScheme, self._dataset.uriRef))

        if isTopConcept:
            g.add(
                (self._dataset.uriRef, SKOS.hasTopConcept, self.uriRef))

        self._addProperties(g)



from .MultiplePointOfInterest import MultiplePointOfInterest
from .POINameInTime import POINameInTime
from .PointOfInterest import PointOfInterest
from .PointOfInterestCategory import PointOfInterestCategory
from .POIState import POIState



from __future__ import annotations

from typing import TYPE_CHECKING, List

from rdflib import URIRef

from ..ns import *
from .TemporalEntity import TemporalEntity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..Thing import Thing


class MonthOfYear(TemporalEntity):
    __type__ = TI["MonthOfYear"]

    isMonthOfYearOf: List[Thing] = []
    month: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for isMonthOfYearOf in self.isMonthOfYearOf:
            g.add((self.uriRef, TI["isMonthOfYearOf"],
                  isMonthOfYearOf.uriRef))

        if self.month:
            g.add((self.uriRef, TI["month"], self.month))


class January(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["January"])


class February(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["February"])


class March(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["March"])


class April(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["April"])


class May(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["May"])


class June(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["June"])


class July(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["July"])


class August(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["August"])


class September(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["September"])


class October(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["October"])


class November(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["November"])


class December(MonthOfYear):
    def __init__(self):
        self.uriRef = URIRef(TI["December"])



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class EducationLevel(Characteristic):
    __type__ = CPV["EducationLevel"]

    educationLevelDesc: List[Literal] = None
    educationLevelID: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.educationLevelDesc:
            for educationLevelDesc in self.educationLevelDesc:
                g.add(
                    (self.uriRef, CPV["educationLevelDesc"], educationLevelDesc))

        if self.educationLevelID:
            g.add((self.uriRef, CPV["educationLevelID"], self.educationLevelID))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Activity import Activity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.Agent import Agent
    from .TransparencyActivityTypology import TransparencyActivityTypology
    from .TransparencyObligation import TransparencyObligation
    from .TransparencyResource import TransparencyResource


class TransparencyActivity(Activity):
    __type__ = TRANSP["TransparencyActivity"]

    generatesResource: List[TransparencyResource] = None
    hasTransparencyActivityTypology: List[TransparencyActivityTypology] = None
    triggeredBy: List[TransparencyObligation] = None
    isPerformedByAgent: Agent = None
    date: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.generatesResource:
            for generatesResource in self.generatesResource:
                g.add(
                    (self.uriRef, TRANSP["generatesResource"], generatesResource.uriRef))

        if self.hasTransparencyActivityTypology:
            for hasTransparencyActivityTypology in self.hasTransparencyActivityTypology:
                g.add((self.uriRef, TRANSP["hasTransparencyActivityTypology"],
                      hasTransparencyActivityTypology.uriRef))

        if self.triggeredBy:
            for triggeredBy in self.triggeredBy:
                g.add((self.uriRef, TRANSP["triggeredBy"], triggeredBy.uriRef))

        if self.isPerformedByAgent:
            g.add(
                (self.uriRef, TRANSP["isPerformedByAgent"], self.isPerformedByAgent.uriRef))

        if self.date:
            g.add((self.uriRef, TI["date"], self.date))



from .AmendmentDocument import AmendmentDocument
from .AmendmentRationale import AmendmentRationale
from .Award import Award
from .AwardCriterion import AwardCriterion
from .AwardNotice import AwardNotice
from .CallForCompetition import CallForCompetition
from .Concession import Concession
from .Contract import Contract
from .CommonProcurementVocabulary import CommonProcurementVocabulary
from .DirectAdministration import DirectAdministration
from .Document import Document
from .EconomicSummary import EconomicSummary
from .FrameworkAgreement import FrameworkAgreement
from .Inspection import Inspection
from .Lot import Lot
from .Notice import Notice
from .NoticeType import NoticeType
from .Payment import Payment
from .PaymentCertificate import PaymentCertificate
from .Procedure import Procedure
from .ProcedureChangeEvent import ProcedureChangeEvent
from .ProcedureType import ProcedureType
from .ProcurementDocument import ProcurementDocument
from .ProcurementProject import ProcurementProject
from .Publication import Publication
from .PublicPrivatePartnership import PublicPrivatePartnership
from .PublicProcurement import PublicProcurement
from .Resolution import Resolution
from .ResolutionDocument import ResolutionDocument
from .ResolutionReason import ResolutionReason
from .ResolutionToContract import ResolutionToContract
from .Suspension import Suspension
from .SuspensionDocument import SuspensionDocument
from .SuspensionReason import SuspensionReason
from .Tender import Tender
from .TenderDocument import TenderDocument
from .TenderSubmission import TenderSubmission
from .Variant import Variant
from .VariantDocument import VariantDocument
from .VariantReason import VariantReason
from .WorkProgressReport import WorkProgressReport



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .AmendmentDocument import AmendmentDocument

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .SuspensionReason import SuspensionReason


class SuspensionDocument(AmendmentDocument):
    __type__ = PUBC["SuspensionDocument"]

    suspensionReason: List[SuspensionReason] = None
    resumptionDate: List[Literal] = None
    suspensionDate: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.suspensionReason:
            for suspensionReason in self.suspensionReason:
                g.add(
                    (self.uriRef, PUBC["suspensionReason"], suspensionReason.uriRef))

        if self.resumptionDate:
            for resumptionDate in self.resumptionDate:
                g.add((self.uriRef, PUBC["resumptionDate"], resumptionDate))

        if self.suspensionDate:
            for suspensionDate in self.suspensionDate:
                g.add((self.uriRef, PUBC["suspensionDate"], suspensionDate))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .ContactPoint import ContactPoint

if TYPE_CHECKING:
    from rdflib import Graph

    from ..Thing import Thing
    from .Email import Email
    from .Telephone import Telephone
    from .UserAccount import UserAccount
    from .WebSite import WebSite


class OnlineContactPoint(ContactPoint):
    __type__ = SM["OnlineContactPoint"]

    hasEmail: List[Email] = None
    hasCertifiedEmail: List[Email] = None
    hasTelephone: List[Telephone] = None
    hasUserAccount: List[UserAccount] = None
    hasWebSite: List[WebSite] = None
    isOnlineContactPointOf: List[Thing] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasEmail:
            for hasEmail in self.hasEmail:
                g.add((self.uriRef, SM["hasEmail"], hasEmail.uriRef))

        if self.hasCertifiedEmail:
            for hasCertifiedEmail in self.hasCertifiedEmail:
                g.add(
                    (self.uriRef, SM["hasCertifiedEmail"], hasCertifiedEmail.uriRef))

        if self.hasTelephone:
            for hasTelephone in self.hasTelephone:
                g.add((self.uriRef, SM["hasTelephone"], hasTelephone.uriRef))

        if self.hasUserAccount:
            for hasUserAccount in self.hasUserAccount:
                g.add((self.uriRef, SM["hasUserAccount"],
                      hasUserAccount.uriRef))

        if self.hasWebSite:
            for hasWebSite in self.hasWebSite:
                g.add((self.uriRef, SM["hasWebSite"], hasWebSite.uriRef))

        if self.isOnlineContactPointOf:
            for isOnlineContactPointOf in self.isOnlineContactPointOf:
                g.add(
                    (self.uriRef, SM["isOnlineContactPointOf"], isOnlineContactPointOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .PathStage import PathStage
    from .ServiceType import ServiceType


class SupportService(Object):
    __type__ = PATHS["SupportService"]

    hasServiceType: List[ServiceType] = None
    isSupportServiceOf: List[PathStage] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasServiceType:
            for hasServiceType in self.hasServiceType:
                g.add(
                    (self.uriRef, PATHS["hasServiceType"], hasServiceType.uriRef))

        if self.isSupportServiceOf:
            for isSupportServiceOf in self.isSupportServiceOf:
                g.add(
                    (self.uriRef, PATHS["isSupportServiceOf"], isSupportServiceOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Attribute import Attribute


class SiteDescription(Description):
    __type__ = CIS["SiteDescription"]

    hasAttribute: List[Attribute] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAttribute:
            for hasAttribute in self.hasAttribute:
                g.add((self.uriRef, CIS["hasAttribute"], hasAttribute.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Post import Post

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Rating import Rating


class Review(Post):
    __type__ = SM["Review"]

    hasRating: List[Rating] = None
    reviewAspect: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasRating:
            for hasRating in self.hasRating:
                g.add((self.uriRef, SM["hasRating"], hasRating.uriRef))

        if self.reviewAspect:
            g.add((self.uriRef, SM["reviewAspect"], self.reviewAspect))



from .ContactPoint import ContactPoint
from .Email import Email
from .EmailType import EmailType
from .Image import Image
from .OnlineContactPoint import OnlineContactPoint
from .PhysicalContactPoint import PhysicalContactPoint
from .Post import Post
from .Rating import Rating
from .Review import Review
from .SocialMedia import SocialMedia
from .Telephone import Telephone
from .TelephoneType import TelephoneType
from .UserAccount import UserAccount
from .WebSite import WebSite



from __future__ import annotations

from typing import TYPE_CHECKING, List

from rdflib import URIRef

from ..l0.Topic import Topic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .Path import Path


class PathTheme(Topic):
    __type__ = PATHS["PathTheme"]

    isThemeOf: List[Path] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isThemeOf:
            for isThemeOf in self.isThemeOf:
                g.add((self.uriRef, PATHS["isThemeOf"], isThemeOf.uriRef))


class Archaeological(PathTheme):
    def __init__(self):
        self.uriRef = URIRef(PATHS["Archaeological"])


class Cultural(PathTheme):
    def __init__(self):
        self.uriRef = URIRef(PATHS["Cultural"])


class Historical(PathTheme):
    def __init__(self):
        self.uriRef = URIRef(PATHS["Historical"])


class Naturalistic(PathTheme):
    def __init__(self):
        self.uriRef = URIRef(PATHS["Naturalistic"])


class Religious(PathTheme):
    def __init__(self):
        self.uriRef = URIRef(PATHS["Religious"])



from __future__ import annotations

from typing import TYPE_CHECKING

from rdflib import Graph, Literal

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .EmailType import EmailType
    from .OnlineContactPoint import OnlineContactPoint


class Email(Object):
    __type__ = SM["Email"]

    hasEmailType: EmailType = None
    isEmailOf: OnlineContactPoint = None
    emailAddress: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasEmailType:
            g.add((self.uriRef, SM["hasEmailType"], self.hasEmailType.uriRef))

        if self.isEmailOf:
            g.add((self.uriRef, SM["isEmailOf"], self.isEmailOf.uriRef))

        if self.emailAddress:
            g.add((self.uriRef, SM["emailAddress"], self.emailAddress))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..clv.Feature import Feature
    from ..cov.Organization import Organization
    from ..l0.Agent import Agent
    from ..l0.Entity import Entity
    from ..ro.TimeIndexedRole import TimeIndexedRole
    from ..sm.OnlineContactPoint import OnlineContactPoint
    from ..ti.Duration import Duration
    from .Call import Call
    from .Programme import Programme
    from .Summary import Summary
    from .UniqueProjectCode import UniqueProjectCode


class PublicInvestmentProject(Description):
    __type__ = PROJ["PublicInvestmentProject"]

    hasProgramme: List[Programme] = None
    projectFunder: List[Organization] = None
    hasSpatialCoverage: List[Feature] = None
    hasParticipantingAgent: List[Agent] = None
    hasRiT: List[TimeIndexedRole] = None
    involvesEntity: List[Entity] = None
    hasDuration: Duration = None
    hasCall: Call = None
    hasSummary: Summary = None
    hasUniqueProjectCode: UniqueProjectCode = None
    hasOnlineContactPoint: OnlineContactPoint = None
    projectTitle: List[Literal] = None
    projectKeyword: List[Literal] = None
    uniqueProjectCodeValue: Literal = None
    projectAcronym: Literal = None
    projectTotalCost: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasProgramme:
            for hasProgramme in self.hasProgramme:
                g.add((self.uriRef, PROJ["hasProgramme"], hasProgramme.uriRef))

        if self.projectFunder:
            for projectFunder in self.projectFunder:
                g.add(
                    (self.uriRef, PROJ["projectFunder"], projectFunder.uriRef))

        if self.hasSpatialCoverage:
            for hasSpatialCoverage in self.hasSpatialCoverage:
                g.add(
                    (self.uriRef, CLV["hasSpatialCoverage"], hasSpatialCoverage.uriRef))

        if self.hasParticipantingAgent:
            for hasParticipantingAgent in self.hasParticipantingAgent:
                g.add(
                    (self.uriRef, PROJ["hasParticipantingAgent"], hasParticipantingAgent.uriRef))

        if self.hasRiT:
            for hasRiT in self.hasRiT:
                g.add((self.uriRef, RO["hasRiT"], hasRiT.uriRef))

        if self.involvesEntity:
            for involvesEntity in self.involvesEntity:
                g.add(
                    (self.uriRef, PROJ["involvesEntity"], involvesEntity.uriRef))

        if self.hasDuration:
            g.add((self.uriRef, TI["hasDuration"], self.hasDuration.uriRef))

        if self.hasCall:
            g.add((self.uriRef, PROJ["hasCall"], self.hasCall.uriRef))

        if self.hasSummary:
            g.add((self.uriRef, PROJ["hasSummary"], self.hasSummary.uriRef))

        if self.hasUniqueProjectCode:
            g.add(
                (self.uriRef, PROJ["hasUniqueProjectCode"], self.hasUniqueProjectCode.uriRef))

        if self.hasOnlineContactPoint:
            g.add((self.uriRef, SM["hasOnlineContactPoint"],
                  self.hasOnlineContactPoint.uriRef))

        if self.projectTitle:
            for projectTitle in self.projectTitle:
                g.add((self.uriRef, PROJ["projectTitle"], projectTitle))

        if self.projectKeyword:
            for projectKeyword in self.projectKeyword:
                g.add((self.uriRef, PROJ["projectKeyword"], projectKeyword))

        if self.uniqueProjectCodeValue:
            g.add(
                (self.uriRef, PROJ["uniqueProjectCodeValue"], self.uniqueProjectCodeValue))

        if self.projectAcronym:
            g.add((self.uriRef, PROJ["projectAcronym"], self.projectAcronym))

        if self.projectTotalCost:
            g.add(
                (self.uriRef, PROJ["projectTotalCost"], self.projectTotalCost))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Activity import Activity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.Entity import Entity
    from ..mu.Value import Value
    from ..ti.TimeInterval import TimeInterval
    from .AccrualPeriodicity import AccrualPeriodicity
    from .CalculationMethod import CalculationMethod
    from .DatumSource import DatumSource
    from .Indicator import Indicator
    from .Metric import Metric


class IndicatorCalculation(Activity):
    __type__ = INDIC["IndicatorCalculation"]

    basedOnMetric: List[Metric] = None
    hasDatumSource: List[DatumSource] = None
    isIndicatorCalculationOf: List[Entity] = None
    computedAtTime: List[TimeInterval] = None
    hasCalculationMethod: List[CalculationMethod] = None
    forIndicator: Indicator = None
    hasIndicatorValue: Value = None
    hasAccrualPeriodicity: AccrualPeriodicity = None
    communcatedAt: Literal = None
    modified: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.basedOnMetric:
            for basedOnMetric in self.basedOnMetric:
                g.add(
                    (self.uriRef, INDIC["basedOnMetric"], basedOnMetric.uriRef))

        if self.hasDatumSource:
            for hasDatumSource in self.hasDatumSource:
                g.add(
                    (self.uriRef, INDIC["hasDatumSource"], hasDatumSource.uriRef))

        if self.isIndicatorCalculationOf:
            for isIndicatorCalculationOf in self.isIndicatorCalculationOf:
                g.add(
                    (self.uriRef, INDIC["isIndicatorCalculationOf"], isIndicatorCalculationOf.uriRef))

        if self.computedAtTime:
            for computedAtTime in self.computedAtTime:
                g.add(
                    (self.uriRef, INDIC["computedAtTime"], computedAtTime.uriRef))

        if self.hasCalculationMethod:
            for hasCalculationMethod in self.hasCalculationMethod:
                g.add(
                    (self.uriRef, INDIC["hasCalculationMethod"], hasCalculationMethod.uriRef))

        if self.forIndicator:
            g.add((self.uriRef, INDIC["forIndicator"],
                  self.forIndicator.uriRef))

        if self.hasIndicatorValue:
            g.add(
                (self.uriRef, INDIC["hasIndicatorValue"], self.hasIndicatorValue.uriRef))

        if self.hasAccrualPeriodicity:
            g.add(
                (self.uriRef, INDIC["hasAccrualPeriodicity"], self.hasAccrualPeriodicity.uriRef))

        if self.communcatedAt:
            g.add((self.uriRef, INDIC["communcatedAt"], self.communcatedAt))

        if self.modified:
            g.add((self.uriRef, TI["modified"], self.modified))



from __future__ import annotations

from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *


class AwardCriterion(Characteristic):
    __type__ = PUBC["AwardCriterion"]


class LowestPrice(AwardCriterion):
    def __init__(self):
        self.uriRef = URIRef(PUBC["LowestPrice"])


class MostEconomicallyAdvantageousTender(AwardCriterion):
    def __init__(self):
        self.uriRef = URIRef(PUBC["MostEconomicallyAdvantageousTender"])



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Activity import Activity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .AmendmentDocument import AmendmentDocument
    from .EconomicSummary import EconomicSummary
    from .Notice import Notice


class ProcurementProject(Activity):
    __type__ = PUBC["ProcurementProject"]

    hasChangeDocument: List[AmendmentDocument] = None
    hasEconomicSummary: List[EconomicSummary] = None
    hasNotice: List[Notice] = None
    description: List[Literal] = None
    auctionBaseAmount: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasChangeDocument:
            for hasChangeDocument in self.hasChangeDocument:
                g.add(
                    (self.uriRef, PUBC["hasChangeDocument"], hasChangeDocument.uriRef))

        if self.hasEconomicSummary:
            for hasEconomicSummary in self.hasEconomicSummary:
                g.add(
                    (self.uriRef, PUBC["hasEconomicSummary"], hasEconomicSummary.uriRef))

        if self.hasNotice:
            for hasNotice in self.hasNotice:
                g.add((self.uriRef, PUBC["hasNotice"], hasNotice.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.auctionBaseAmount:
            for auctionBaseAmount in self.auctionBaseAmount:
                g.add(
                    (self.uriRef, PUBC["auctionBaseAmount"], auctionBaseAmount))



from __future__ import annotations

from ..ns import *
from .CulturalInstituteOrSite import CulturalInstituteOrSite


class ArchaeologicalArea(CulturalInstituteOrSite):
    __type__ = CIS["ArchaeologicalArea"]



from __future__ import annotations

from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *


class TransparencyObligationStatus(Characteristic):
    __type__ = TRANSP["TransparencyObligationStatus"]


class Deprecated(TransparencyObligationStatus):
    def __init__(self):
        self.uriRef = URIRef(TRANSP["Deprecated"])


class InForce(TransparencyObligationStatus):
    def __init__(self):
        self.uriRef = URIRef(TRANSP["InForce"])


from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class Programme(Object):
    __type__ = PROJ["Programme"]

    uniqueProjectCodeValue: Literal = None
    uniqueProjectCodeType: Literal = None  # { "linked" , "master" , "normal" }

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.uniqueProjectCodeValue:
            g.add(
                (self.uriRef, PROJ["uniqueProjectCodeValue"], self.uniqueProjectCodeValue))

        if self.uniqueProjectCodeType:
            g.add(
                (self.uriRef, PROJ["uniqueProjectCodeType"], self.uniqueProjectCodeType))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.EventOrSituation import EventOrSituation
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .EconomicSummary import EconomicSummary


class ProcedureChangeEvent(EventOrSituation):
    __type__ = PUBC["ProcedureChangeEvent"]

    hasOriginalSummary: List[EconomicSummary] = None
    hasResultingSummary: List[EconomicSummary] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasOriginalSummary:
            for hasOriginalSummary in self.hasOriginalSummary:
                g.add(
                    (self.uriRef, PUBC["hasOriginalSummary"], hasOriginalSummary.uriRef))

        if self.hasResultingSummary:
            for hasResultingSummary in self.hasResultingSummary:
                g.add(
                    (self.uriRef, PUBC["hasResultingSummary"], hasResultingSummary.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..poi.PointOfInterest import PointOfInterest
from .CulturalEntity import CulturalEntity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..accesscondition.AccessCondition import AccessCondition
    from ..clv.Feature import Feature
    from ..pot.Ticket import Ticket
    from ..ro.TimeIndexedRole import TimeIndexedRole
    from ..sm.OnlineContactPoint import OnlineContactPoint
    from .Catalogue import Catalogue
    from .CISNameInTime import CISNameInTime
    from .CISService import CISService
    from .CISType import CISType
    from .CollectionCulEnt import CollectionCulEnt
    from .CreativeWork import CreativeWork
    from .CulturalProject import CulturalProject
    from .Equipment import Equipment
    from .Site import Site
    from .SubjectDiscipline import SubjectDiscipline


class CulturalInstituteOrSite(CulturalEntity, PointOfInterest):
    __type__ = CIS["CulturalInstituteOrSite"]

    hasCISType: List[CISType] = None
    hasSite: List[Site] = None
    hasRiT: List[TimeIndexedRole] = None
    catalogue: List[Catalogue] = None
    hasCISNameInTime: List[CISNameInTime] = None
    hasCollection: List[CollectionCulEnt] = None
    hasDiscipline: List[SubjectDiscipline] = None
    isInvolvedInProject: List[CulturalProject] = None
    isPartOf: List[CulturalInstituteOrSite] = None
    isSubjectOf: List[CreativeWork] = None
    makesAvailableEquipment: List[Equipment] = None
    providesService: List[CISService] = None
    hasAccessCondition: List[AccessCondition] = None
    hasOnlineContactPoint: List[OnlineContactPoint] = None
    hasSpatialCoverage: List[Feature] = None
    hasTicket: List[Ticket] = None
    institutionalCISName: List[Literal] = None
    description: List[Literal] = None
    ISILIdentifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCISType:
            for hasCISType in self.hasCISType:
                g.add((self.uriRef, CIS["hasCISType"], hasCISType.uriRef))

        if self.hasSite:
            for hasSite in self.hasSite:
                g.add((self.uriRef, CIS["hasSite"], hasSite.uriRef))

        if self.hasRiT:
            for hasRiT in self.hasRiT:
                g.add((self.uriRef, RO["hasRiT"], hasRiT.uriRef))

        if self.catalogue:
            for catalogue in self.catalogue:
                g.add((self.uriRef, CIS["catalogue"], catalogue.uriRef))

        if self.hasCISNameInTime:
            for hasCISNameInTime in self.hasCISNameInTime:
                g.add(
                    (self.uriRef, CIS["hasCISNameInTime"], hasCISNameInTime.uriRef))

        if self.hasCollection:
            for hasCollection in self.hasCollection:
                g.add(
                    (self.uriRef, CIS["hasCollection"], hasCollection.uriRef))

        if self.hasDiscipline:
            for hasDiscipline in self.hasDiscipline:
                g.add(
                    (self.uriRef, CIS["hasDiscipline"], hasDiscipline.uriRef))

        if self.isInvolvedInProject:
            for isInvolvedInProject in self.isInvolvedInProject:
                g.add(
                    (self.uriRef, CIS["isInvolvedInProject"], isInvolvedInProject.uriRef))

        if self.isPartOf:
            for isPartOf in self.isPartOf:
                g.add((self.uriRef, CIS["isPartOf"], isPartOf.uriRef))

        if self.isSubjectOf:
            for isSubjectOf in self.isSubjectOf:
                g.add((self.uriRef, CIS["isSubjectOf"], isSubjectOf.uriRef))

        if self.makesAvailableEquipment:
            for makesAvailableEquipment in self.makesAvailableEquipment:
                g.add(
                    (self.uriRef, CIS["makesAvailableEquipment"], makesAvailableEquipment.uriRef))

        if self.providesService:
            for providesService in self.providesService:
                g.add(
                    (self.uriRef, CIS["providesService"], providesService.uriRef))

        if self.hasAccessCondition:
            for hasAccessCondition in self.hasAccessCondition:
                g.add(
                    (self.uriRef, ACOND["hasAccessCondition"], hasAccessCondition.uriRef))

        if self.hasOnlineContactPoint:
            for hasOnlineContactPoint in self.hasOnlineContactPoint:
                g.add(
                    (self.uriRef, SM["hasOnlineContactPoint"], hasOnlineContactPoint.uriRef))

        if self.hasSpatialCoverage:
            for hasSpatialCoverage in self.hasSpatialCoverage:
                g.add(
                    (self.uriRef, CLV["hasSpatialCoverage"], hasSpatialCoverage.uriRef))

        if self.hasTicket:
            for hasTicket in self.hasTicket:
                g.add((self.uriRef, POT["hasTicket"], hasTicket.uriRef))

        if self.institutionalCISName:
            for institutionalCISName in self.institutionalCISName:
                g.add(
                    (self.uriRef, CIS["institutionalCISName"], institutionalCISName))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.ISILIdentifier:
            g.add((self.uriRef, CIS["ISILIdentifier"], self.ISILIdentifier))



from __future__ import annotations

from typing import TYPE_CHECKING, List, Union

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.EventOrSituation import EventOrSituation
    from ..l0.Location import Location
    from .Validity import Validity


class Ticket(Object):
    __type__ = POT["Ticket"]

    hasValidity: List[Validity] = None
    description: List[Literal] = None
    forAccessTo: List[Union[EventOrSituation, Location]] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasValidity:
            for hasValidity in self.hasValidity:
                g.add((self.uriRef, POT["hasValidity"], hasValidity.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.forAccessTo:
            for forAccessTo in self.forAccessTo:
                g.add((self.uriRef, POT["forAccessTo"], forAccessTo.uriRef))


from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .PointOfInterest import PointOfInterest


class POIState(Characteristic):
    __type__ = POI["POIState"]

    POIstate: List[Literal] = None
    isPOIStateFor: List[PointOfInterest] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.POIstate:
            for POIstate in self.POIstate:
                g.add((self.uriRef, POI["POIstate"], POIstate))

        if self.isPOIStateFor:
            for isPOIStateFor in self.isPOIStateFor:
                g.add(
                    (self.uriRef, POI["isPOIStateFor"], isPOIStateFor.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Currency import Currency


class PriceSpecification(Characteristic):
    __type__ = POT["PriceSpecification"]

    hasCurrency: List[Currency] = None
    hasCurrencyValue: List[Literal] = None
    VAT: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCurrency:
            for hasCurrency in self.hasCurrency:
                g.add((self.uriRef, POT["hasCurrency"], hasCurrency.uriRef))

        if self.hasCurrencyValue:
            for hasCurrencyValue in self.hasCurrencyValue:
                g.add((self.uriRef, POT["hasCurrencyValue"], hasCurrencyValue))

        if self.VAT:
            g.add((self.uriRef, POT["VAT"], self.VAT))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .ProcurementDocument import ProcurementDocument

if TYPE_CHECKING:
    from rdflib import Graph

    from .AmendmentRationale import AmendmentRationale


class AmendmentDocument(ProcurementDocument):
    __type__ = PUBC["AmendmentDocument"]

    hasAmendmentRationale: List[AmendmentRationale] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAmendmentRationale:
            for hasAmendmentRationale in self.hasAmendmentRationale:
                g.add(
                    (self.uriRef, PUBC["hasAmendmentRationale"], hasAmendmentRationale.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..sm.OnlineContactPoint import OnlineContactPoint
    from .CulturalInstituteOrSite import CulturalInstituteOrSite


class CISService(Characteristic):
    __type__ = CIS["CISService"]

    isProvidedBy: List[CulturalInstituteOrSite] = None
    hasOnlineContactPoint: List[OnlineContactPoint] = None
    name: List[Literal] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isProvidedBy:
            for isProvidedBy in self.isProvidedBy:
                g.add(
                    (self.uriRef, CIS["isProvidedBy"], isProvidedBy.uriRef))

        if self.hasOnlineContactPoint:
            for hasOnlineContactPoint in self.hasOnlineContactPoint:
                g.add(
                    (self.uriRef, SM["hasOnlineContactPoint"], hasOnlineContactPoint.uriRef))

        if self.name:
            for name in self.name:
                g.add(
                    (self.uriRef, L0["name"], name))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *


class Paving(Characteristic):
    __type__ = PATHS["Paving"]


class Asphalt(Paving):
    def __init__(self):
        self.uriRef = URIRef(PATHS["asphalt"])


from __future__ import annotations

from typing import TYPE_CHECKING, List, Union

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..cov.Organization import Organization
    from ..cov.PublicOrganizationCategory import PublicOrganizationCategory
    from .TransparencyActivity import TransparencyActivity
    from .TransparencyDataTypology import TransparencyDataTypology
    from .TransparencyObligationStatus import TransparencyObligationStatus
    from .TransparencySubject import TransparencySubject
    from .UpdateFrequency import UpdateFrequency


class TransparencyObligation(Description):
    __type__ = TRANSP["TransparencyObligation"]

    appliesToOrganization: List[Union[Organization,
                                      PublicOrganizationCategory]] = None
    isClassifiedBy: List[TransparencyDataTypology] = None
    hasTransparencyStatus: List[TransparencyObligationStatus] = None
    definesUpdateFrequency: List[UpdateFrequency] = None
    hasTransparencySubject: List[TransparencySubject] = None
    subTransparencyObligationOf: List[TransparencyObligation] = None
    superTransparencyObligationOf: List[TransparencyObligation] = None
    triggers: List[TransparencyActivity] = None
    atTime: List[Literal] = None
    regulationReference: List[Literal] = None
    exceptionObligationNote: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.appliesToOrganization:
            for appliesToOrganization in self.appliesToOrganization:
                g.add(
                    (self.uriRef, TRANSP["appliesToOrganization"], appliesToOrganization.uriRef))

        if self.isClassifiedBy:
            for isClassifiedBy in self.isClassifiedBy:
                g.add(
                    (self.uriRef, TRANSP["isClassifiedBy"], isClassifiedBy.uriRef))

        if self.hasTransparencyStatus:
            for hasTransparencyStatus in self.hasTransparencyStatus:
                g.add(
                    (self.uriRef, TRANSP["hasTransparencyStatus"], hasTransparencyStatus.uriRef))

        if self.definesUpdateFrequency:
            for definesUpdateFrequency in self.definesUpdateFrequency:
                g.add(
                    (self.uriRef, TRANSP["definesUpdateFrequency"], definesUpdateFrequency.uriRef))

        if self.hasTransparencySubject:
            for hasTransparencySubject in self.hasTransparencySubject:
                g.add(
                    (self.uriRef, TRANSP["hasTransparencySubject"], hasTransparencySubject.uriRef))

        if self.subTransparencyObligationOf:
            for subTransparencyObligationOf in self.subTransparencyObligationOf:
                g.add(
                    (self.uriRef, TRANSP["subTransparencyObligationOf"], subTransparencyObligationOf.uriRef))

        if self.superTransparencyObligationOf:
            for superTransparencyObligationOf in self.superTransparencyObligationOf:
                g.add(
                    (self.uriRef, TRANSP["superTransparencyObligationOf"], superTransparencyObligationOf.uriRef))

        if self.triggers:
            for triggers in self.triggers:
                g.add((self.uriRef, TRANSP["triggers"], triggers.uriRef))

        if self.atTime:
            for atTime in self.atTime:
                g.add((self.uriRef, TI["atTime"], atTime))

        if self.regulationReference:
            for regulationReference in self.regulationReference:
                g.add(
                    (self.uriRef, TRANSP["regulationReference"], regulationReference))

        if self.exceptionObligationNote:
            for exceptionObligationNote in self.exceptionObligationNote:
                g.add(
                    (self.uriRef, TRANSP["exceptionObligationNote"], exceptionObligationNote))



from __future__ import annotations

from ..ns import *
from .CulturalInstituteOrSite import CulturalInstituteOrSite


class HolderOfArchive(CulturalInstituteOrSite):
    __type__ = CIS["HolderOfArchive"]



from __future__ import annotations

from typing import TYPE_CHECKING, List, Literal

from ..ns import *
from .ProcurementProject import ProcurementProject

if TYPE_CHECKING:
    from rdflib import Graph

    from .AwardCriterion import AwardCriterion
    from .AwardNotice import AwardNotice
    from .Contract import Contract
    from .CommonProcurementVocabulary import CommonProcurementVocabulary
    from .PaymentCertificate import PaymentCertificate
    from .Procedure import Procedure
    from .WorkProgressReport import WorkProgressReport


class Contract(ProcurementProject):
    __type__ = PUBC["Contract"]

    hasCPV: List[CommonProcurementVocabulary] = None
    hasContract: List[Contract] = None
    hasAwardCriterion: List[AwardCriterion] = None
    hasAwardNotice: List[AwardNotice] = None
    hasPaymentCertificate: List[PaymentCertificate] = None
    hasWorkProgressReport: List[WorkProgressReport] = None
    isIncludedInProcedure: Procedure = None
    actualEndDate: List[Literal] = None
    actualStartDate: List[Literal] = None
    currentAvailableAmount: List[Literal] = None
    currentEstimatedEndDate: List[Literal] = None
    currentPlanningAmount: List[Literal] = None
    currentSafetyAmount: List[Literal] = None
    currentServicesAmount: List[Literal] = None
    currentSuppliesAmount: List[Literal] = None
    currentTotalAmount: List[Literal] = None
    currentWorksAmount: List[Literal] = None
    specialSector: List[Literal] = None
    totalAmountPaid: List[Literal] = None
    CIG: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCPV:
            for hasCPV in self.hasCPV:
                g.add((self.uriRef, PUBC["hasCPV"], hasCPV.uriRef))

        if self.hasContract:
            for hasContract in self.hasContract:
                g.add((self.uriRef, PUBC["hasContract"], hasContract.uriRef))

        if self.hasAwardCriterion:
            for hasAwardCriterion in self.hasAwardCriterion:
                g.add(
                    (self.uriRef, PUBC["hasAwardCriterion"], hasAwardCriterion.uriRef))

        if self.hasAwardNotice:
            for hasAwardNotice in self.hasAwardNotice:
                g.add(
                    (self.uriRef, PUBC["hasAwardNotice"], hasAwardNotice.uriRef))

        if self.hasPaymentCertificate:
            for hasPaymentCertificate in self.hasPaymentCertificate:
                g.add(
                    (self.uriRef, PUBC["hasPaymentCertificate"], hasPaymentCertificate.uriRef))

        if self.hasWorkProgressReport:
            for hasWorkProgressReport in self.hasWorkProgressReport:
                g.add(
                    (self.uriRef, PUBC["hasWorkProgressReport"], hasWorkProgressReport.uriRef))

        if self.isIncludedInProcedure:
            g.add((self.uriRef, PUBC["isIncludedInProcedure"],
                  self.isIncludedInProcedure.uriRef))

        if self.actualEndDate:
            for actualEndDate in self.actualEndDate:
                g.add((self.uriRef, PUBC["actualEndDate"], actualEndDate))

        if self.actualStartDate:
            for actualStartDate in self.actualStartDate:
                g.add((self.uriRef, PUBC["actualStartDate"], actualStartDate))

        if self.currentAvailableAmount:
            for currentAvailableAmount in self.currentAvailableAmount:
                g.add(
                    (self.uriRef, PUBC["currentAvailableAmount"], currentAvailableAmount))

        if self.currentEstimatedEndDate:
            for currentEstimatedEndDate in self.currentEstimatedEndDate:
                g.add(
                    (self.uriRef, PUBC["currentEstimatedEndDate"], currentEstimatedEndDate))

        if self.currentPlanningAmount:
            for currentPlanningAmount in self.currentPlanningAmount:
                g.add(
                    (self.uriRef, PUBC["currentPlanningAmount"], currentPlanningAmount))

        if self.currentSafetyAmount:
            for currentSafetyAmount in self.currentSafetyAmount:
                g.add(
                    (self.uriRef, PUBC["currentSafetyAmount"], currentSafetyAmount))

        if self.currentServicesAmount:
            for currentServicesAmount in self.currentServicesAmount:
                g.add(
                    (self.uriRef, PUBC["currentServicesAmount"], currentServicesAmount))

        if self.currentSuppliesAmount:
            for currentSuppliesAmount in self.currentSuppliesAmount:
                g.add(
                    (self.uriRef, PUBC["currentSuppliesAmount"], currentSuppliesAmount))

        if self.currentTotalAmount:
            for currentTotalAmount in self.currentTotalAmount:
                g.add(
                    (self.uriRef, PUBC["currentTotalAmount"], currentTotalAmount))

        if self.currentWorksAmount:
            for currentWorksAmount in self.currentWorksAmount:
                g.add(
                    (self.uriRef, PUBC["currentWorksAmount"], currentWorksAmount))

        if self.specialSector:
            for specialSector in self.specialSector:
                g.add((self.uriRef, PUBC["specialSector"], specialSector))

        if self.totalAmountPaid:
            for totalAmountPaid in self.totalAmountPaid:
                g.add((self.uriRef, PUBC["totalAmountPaid"], totalAmountPaid))

        if self.CIG:
            g.add((self.uriRef, PUBC["CIG"], self.CIG))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .Pathway import Pathway


class SecurityLevel(Characteristic):
    __type__ = PATHS["SecurityLevel"]

    isSecurityLevelOf: List[Pathway] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isSecurityLevelOf:
            for isSecurityLevelOf in self.isSecurityLevelOf:
                g.add(
                    (self.uriRef, PATHS["isSecurityLevelOf"], isSecurityLevelOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..mu.Value import Value


class Parameter(Characteristic):
    __type__ = INDIC["Parameter"]

    parametrizes: List[Value] = None
    subParameter: List[Parameter] = None
    superParameter: List[Parameter] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.parametrizes:
            for parametrizes in self.parametrizes:
                g.add(
                    (self.uriRef, INDIC["parametrizes"], parametrizes.uriRef))

        if self.subParameter:
            for subParameter in self.subParameter:
                g.add(
                    (self.uriRef, INDIC["subParameter"], subParameter.uriRef))

        if self.superParameter:
            for superParameter in self.superParameter:
                g.add(
                    (self.uriRef, INDIC["superParameter"], superParameter.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Observation import Observation
    from .ObservationValue import ObservationValue


class ObservationParameter(Characteristic):
    __type__ = IOT["ObservationParameter"]

    hasValueForObservationParameter: List[ObservationValue] = None
    isObservationParameterFor: List[Observation] = None
    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasValueForObservationParameter:
            for hasValueForObservationParameter in self.hasValueForObservationParameter:
                g.add((self.uriRef, IOT["hasValueForObservationParameter"],
                      hasValueForObservationParameter.uriRef))

        if self.isObservationParameterFor:
            for isObservationParameterFor in self.isObservationParameterFor:
                g.add(
                    (self.uriRef, IOT["isObservationParameterFor"], isObservationParameterFor.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class OSDFeature(Characteristic):
    __type__ = ACCO["OSDFeature"]

    featureName: List[Literal] = None
    featureDescription: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.featureName:
            for featureName in self.featureName:
                g.add((self.uriRef, ACCO["featureName"], featureName))

        if self.featureDescription:
            for featureDescription in self.featureDescription:
                g.add(
                    (self.uriRef, ACCO["featureDescription"], featureDescription))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..l0.Characteristic import Characteristic

if TYPE_CHECKING:
    from rdflib import Graph

    from .MeasurementQualityValue import MeasurementQualityValue


class MeasurementQuality(Characteristic):
    __type__ = IOT["MeasurementQuality"]

    hasMeasurementQualityValue: List[MeasurementQualityValue] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasMeasurementQualityValue:
            for hasMeasurementQualityValue in self.hasMeasurementQualityValue:
                g.add(
                    (self.uriRef, IOT["hasMeasurementQualityValue"], hasMeasurementQualityValue.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from ..ti.TimeIndexedEvent import TimeIndexedEvent

if TYPE_CHECKING:
    from rdflib import Graph

    from ..clv.Address import Address
    from .Person import Person


class ResidenceInTime(TimeIndexedEvent):
    __type__ = CPV["ResidenceInTime"]

    residenceInLocation: Address = None
    isResidenceInTimeOf: Person = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.residenceInLocation:
            g.add((self.uriRef, CPV["residenceInLocation"],
                  self.residenceInLocation.uriRef))

        if self.isResidenceInTimeOf:
            g.add((self.uriRef, CPV["isResidenceInTimeOf"],
                  self.isResidenceInTimeOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List, Literal

from ..ns import *
from .ProcurementProject import ProcurementProject

if TYPE_CHECKING:
    from rdflib import Graph

    from ..l0.Agent import Agent
    from ..ro.TimeIndexedRole import TimeIndexedRole
    from .CommonProcurementVocabulary import CommonProcurementVocabulary
    from .Lot import Lot
    from .ProcedureType import ProcedureType
    from .ProcurementDocument import ProcurementDocument
    from .ResolutionToContract import ResolutionToContract


class Procedure(ProcurementProject):
    __type__ = PUBC["Procedure"]

    hasCPV: List[CommonProcurementVocabulary] = None
    hasProcurementDocument: List[ProcurementDocument] = None
    includesLot: List[Lot] = None
    holdsRoleInTime: List[TimeIndexedRole] = None
    hasResolutionToContract: List[ResolutionToContract] = None
    hasProcedureType: List[ProcedureType] = None
    hasProcuringEntity: Agent = None
    procedureTotalAmount: List[Literal] = None
    identifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCPV:
            for hasCPV in self.hasCPV:
                g.add((self.uriRef, PUBC["hasCPV"], hasCPV.uriRef))

        if self.hasProcurementDocument:
            for hasProcurementDocument in self.hasProcurementDocument:
                g.add(
                    (self.uriRef, PUBC["hasProcurementDocument"], hasProcurementDocument.uriRef))

        if self.includesLot:
            for includesLot in self.includesLot:
                g.add((self.uriRef, PUBC["includesLot"], includesLot.uriRef))

        if self.holdsRoleInTime:
            for holdsRoleInTime in self.holdsRoleInTime:
                g.add(
                    (self.uriRef, RO["holdsRoleInTime"], holdsRoleInTime.uriRef))

        if self.hasResolutionToContract:
            for hasResolutionToContract in self.hasResolutionToContract:
                g.add(
                    (self.uriRef, PUBC["hasResolutionToContract"], hasResolutionToContract.uriRef))

        if self.hasProcedureType:
            for hasProcedureType in self.hasProcedureType:
                g.add(
                    (self.uriRef, PUBC["hasProcedureType"], hasProcedureType.uriRef))

        if self.hasProcuringEntity:
            g.add((self.uriRef, PUBC["hasProcuringEntity"],
                  self.hasProcuringEntity.uriRef))

        if self.procedureTotalAmount:
            for procedureTotalAmount in self.procedureTotalAmount:
                g.add(
                    (self.uriRef, PUBC["procedureTotalAmount"], procedureTotalAmount))

        if self.identifier:
            g.add((self.uriRef, PUBC["identifier"], self.identifier))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Collection import Collection
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Observation import Observation
    from .Sensor import Sensor


class ObservationCollection(Collection):
    __type__ = IOT["ObservationCollection"]

    consistsOf: List[Observation] = None
    observationCollectionMadeBySensor: Sensor = None
    identifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.consistsOf:
            for consistsOf in self.consistsOf:
                g.add((self.uriRef, IOT["consistsOf"], consistsOf.uriRef))

        if self.observationCollectionMadeBySensor:
            g.add((self.uriRef, IOT["observationCollectionMadeBySensor"],
                  self.observationCollectionMadeBySensor.uriRef))

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..clv.Feature import Feature
    from ..ro.TimeIndexedRole import TimeIndexedRole
    from ..sm.OnlineContactPoint import OnlineContactPoint
    from ..ti.TemporalEntity import TemporalEntity
    from .Authentication import Authentication
    from .Channel import Channel
    from .Cost import Cost
    from .EmailChannel import EmailChannel
    from .Input import Input
    from .OtherElectronicChannel import OtherElectronicChannel
    from .Output import Output
    from .PhoneChannel import PhoneChannel
    from .Rule import Rule
    from .ServiceProcessingTime import ServiceProcessingTime
    from .ServiceStatus import ServiceStatus
    from .WebSiteChannel import WebSiteChannel


class Service(Object):
    __type__ = CPSV["Service"]

    hasAuthenticationMethod: List[Authentication] = None
    hasChannel: List[Channel] = None
    hasRiT: List[TimeIndexedRole] = None
    hasSpatialCoverage: List[Feature] = None
    hasCost: List[Cost] = None
    hasInput: List[Input] = None
    isCompliantWithRule: List[Rule] = None
    isPhysicallyAvailableAt: List[Feature] = None
    producesOutput: List[Output] = None
    relationService: List[Service] = None
    requiresService: List[Service] = None
    hasOnlineContactPoint: List[OnlineContactPoint] = None
    hasTemporalCoverage: List[TemporalEntity] = None
    hasProcessingTime: List[ServiceProcessingTime] = None
    hasWebSiteCh: List[WebSiteChannel] = None
    hasEmailCh: List[EmailChannel] = None
    hasOtherElectronicCh: List[OtherElectronicChannel] = None
    hasPhoneCh: List[PhoneChannel] = None
    hasServiceStatus: ServiceStatus = None
    description: List[Literal] = None
    name: List[Literal] = None
    otherServiceCode: List[Literal] = None
    serviceKeyword: List[Literal] = None
    identifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAuthenticationMethod:
            for hasAuthenticationMethod in self.hasAuthenticationMethod:
                g.add(
                    (self.uriRef, CPSV["hasAuthenticationMethod"], hasAuthenticationMethod.uriRef))

        if self.hasChannel:
            for hasChannel in self.hasChannel:
                g.add((self.uriRef, CPSV["hasChannel"], hasChannel.uriRef))

        if self.hasRiT:
            for hasRiT in self.hasRiT:
                g.add((self.uriRef, RO["hasRiT"], hasRiT.uriRef))

        if self.hasSpatialCoverage:
            for hasSpatialCoverage in self.hasSpatialCoverage:
                g.add(
                    (self.uriRef, CLV["hasSpatialCoverage"], hasSpatialCoverage.uriRef))

        if self.hasCost:
            for hasCost in self.hasCost:
                g.add((self.uriRef, CPSV["hasCost"], hasCost.uriRef))

        if self.hasInput:
            for hasInput in self.hasInput:
                g.add((self.uriRef, CPSV["hasInput"], hasInput.uriRef))

        if self.isCompliantWithRule:
            for isCompliantWithRule in self.isCompliantWithRule:
                g.add(
                    (self.uriRef, CPSV["isCompliantWithRule"], isCompliantWithRule.uriRef))

        if self.isPhysicallyAvailableAt:
            for isPhysicallyAvailableAt in self.isPhysicallyAvailableAt:
                g.add(
                    (self.uriRef, CPSV["isPhysicallyAvailableAt"], isPhysicallyAvailableAt.uriRef))

        if self.producesOutput:
            for producesOutput in self.producesOutput:
                g.add(
                    (self.uriRef, CPSV["producesOutput"], producesOutput.uriRef))

        if self.relationService:
            for relationService in self.relationService:
                g.add(
                    (self.uriRef, CPSV["relationService"], relationService.uriRef))

        if self.requiresService:
            for requiresService in self.requiresService:
                g.add(
                    (self.uriRef, CPSV["requiresService"], requiresService.uriRef))

        if self.hasOnlineContactPoint:
            for hasOnlineContactPoint in self.hasOnlineContactPoint:
                g.add(
                    (self.uriRef, SM["hasOnlineContactPoint"], hasOnlineContactPoint.uriRef))

        if self.hasTemporalCoverage:
            for hasTemporalCoverage in self.hasTemporalCoverage:
                g.add(
                    (self.uriRef, TI["hasTemporalCoverage"], hasTemporalCoverage.uriRef))

        if self.hasProcessingTime:
            for hasProcessingTime in self.hasProcessingTime:
                g.add(
                    (self.uriRef, CPSV["hasProcessingTime"], hasProcessingTime.uriRef))

        if self.hasWebSiteCh:
            for hasWebSiteCh in self.hasWebSiteCh:
                g.add((self.uriRef, CPSV["hasWebSiteCh"], hasWebSiteCh.uriRef))

        if self.hasEmailCh:
            for hasEmailCh in self.hasEmailCh:
                g.add((self.uriRef, CPSV["hasEmailCh"], hasEmailCh.uriRef))

        if self.hasOtherElectronicCh:
            for hasOtherElectronicCh in self.hasOtherElectronicCh:
                g.add(
                    (self.uriRef, CPSV["hasOtherElectronicCh"], hasOtherElectronicCh.uriRef))

        if self.hasPhoneCh:
            for hasPhoneCh in self.hasPhoneCh:
                g.add((self.uriRef, CPSV["hasPhoneCh"], hasPhoneCh.uriRef))

        if self.hasServiceStatus:
            g.add((self.uriRef, CPSV["hasServiceStatus"],
                  self.hasServiceStatus.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.otherServiceCode:
            for otherServiceCode in self.otherServiceCode:
                g.add(
                    (self.uriRef, CPSV["otherServiceCode"], otherServiceCode))

        if self.serviceKeyword:
            for serviceKeyword in self.serviceKeyword:
                g.add((self.uriRef, CPSV["serviceKeyword"], serviceKeyword))

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .CreativeWork import CreativeWork

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class AudioObject(CreativeWork):
    __type__ = CIS["AudioObject"]

    URL: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.URL:
            for URL in self.URL:
                g.add((self.uriRef, SM["URL"], URL))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .Document import Document

if TYPE_CHECKING:
    from rdflib import Graph

    from .Tender import Tender


class TenderDocument(Document):
    __type__ = PUBC["TenderDocument"]

    refersToTender: Tender = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.refersToTender:
            g.add((self.uriRef, PUBC["refersToTender"],
                  self.refersToTender.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Notice import Notice

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.Agent import Agent


class AwardNotice(Notice):
    __type__ = PUBC["AwardNotice"]

    winner: List[Agent] = None
    agreedAmount: List[Literal] = None
    outcomeDate: List[Literal] = None
    reductionPercentage: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.winner:
            for winner in self.winner:
                g.add((self.uriRef, PUBC["winner"], winner.uriRef))

        if self.agreedAmount:
            for agreedAmount in self.agreedAmount:
                g.add((self.uriRef, PUBC["agreedAmount"], agreedAmount))

        if self.outcomeDate:
            for outcomeDate in self.outcomeDate:
                g.add((self.uriRef, PUBC["outcomeDate"], outcomeDate))

        if self.reductionPercentage:
            for reductionPercentage in self.reductionPercentage:
                g.add(
                    (self.uriRef, PUBC["reductionPercentage"], reductionPercentage))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .IndicatorCalculation import IndicatorCalculation
    from .IndicatorType import IndicatorType
    from .Purpose import Purpose


class Indicator(Characteristic):
    __type__ = INDIC["Indicator"]

    meetsPurpose: List[Purpose] = None
    computedInIndicatorCalculation: List[IndicatorCalculation] = None
    subIndicator: List[Indicator] = None
    superIndicator: List[Indicator] = None
    hasIndicatorType: IndicatorType = None
    name: List[Literal] = None
    definedInLegislation: List[Literal] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.meetsPurpose:
            for meetsPurpose in self.meetsPurpose:
                g.add(
                    (self.uriRef, INDIC["meetsPurpose"], meetsPurpose.uriRef))

        if self.computedInIndicatorCalculation:
            for computedInIndicatorCalculation in self.computedInIndicatorCalculation:
                g.add((self.uriRef, INDIC["computedInIndicatorCalculation"],
                      computedInIndicatorCalculation.uriRef))

        if self.subIndicator:
            for subIndicator in self.subIndicator:
                g.add(
                    (self.uriRef, INDIC["subIndicator"], subIndicator.uriRef))

        if self.superIndicator:
            for superIndicator in self.superIndicator:
                g.add(
                    (self.uriRef, INDIC["superIndicator"], superIndicator.uriRef))

        if self.hasIndicatorType:
            g.add(
                (self.uriRef, INDIC["hasIndicatorType"], self.hasIndicatorType.uriRef))

        if self.name:
            for name in self.name:
                g.add(
                    (self.uriRef, L0["name"], name))

        if self.definedInLegislation:
            for definedInLegislation in self.definedInLegislation:
                g.add(
                    (self.uriRef, INDIC["definedInLegislation"], definedInLegislation))

        if self.description:
            for description in self.description:
                g.add(
                    (self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .Channel import Channel

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class WebSiteChannel(Channel):
    __type__ = CPSV["WebSiteChannel"]

    URL: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.URL:
            g.add((self.uriRef, SM["URL"], self.URL))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .TemporalEntity import TemporalEntity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .TimeInstant import TimeInstant


class TimeInterval(TemporalEntity):
    __type__ = TI["TimeInterval"]

    hasTimeInstantInside: List[TimeInstant] = []
    date: List[Literal] = []
    endTime: Literal = None
    startTime: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for hasTimeInstantInside in self.hasTimeInstantInside:
            g.add((self.uriRef, TI["hasTimeInstantInside"],
                  hasTimeInstantInside.uriRef))

        for date in self.date:
            g.add((self.uriRef, TI["date"], date.uriRef))

        if self.endTime:
            g.add((self.uriRef, TI["endTime"], self.endTime))

        if self.startTime:
            g.add((self.uriRef, TI["startTime"], self.startTime))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Entity import Entity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..l0.Agent import Agent
    from .Lot import Lot
    from .TenderDocument import TenderDocument
    from .TenderSubmission import TenderSubmission


class Tender(Entity):
    __type__ = PUBC["Tender"]

    appliesToLot: List[Lot] = None
    attachesTenderDocument: List[TenderDocument] = None
    tenderer: List[Agent] = None
    submittedDuring: TenderSubmission = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.appliesToLot:
            for appliesToLot in self.appliesToLot:
                g.add((self.uriRef, PUBC["appliesToLot"], appliesToLot.uriRef))

        if self.attachesTenderDocument:
            for attachesTenderDocument in self.attachesTenderDocument:
                g.add(
                    (self.uriRef, PUBC["attachesTenderDocument"], attachesTenderDocument.uriRef))

        if self.tenderer:
            for tenderer in self.tenderer:
                g.add((self.uriRef, PUBC["tenderer"], tenderer.uriRef))

        if self.submittedDuring:
            g.add((self.uriRef, PUBC["submittedDuring"],
                  self.submittedDuring.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .Service import Service


class ServiceStatus(Characteristic):
    __type__ = CPSV["ServiceStatus"]

    isStatusForService: List[Service] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isStatusForService:
            for isStatusForService in self.isStatusForService:
                g.add(
                    (self.uriRef, CPSV["isStatusForService"], isStatusForService.uriRef))


class Active(ServiceStatus):
    def __init__(self):
        self.uriRef = URIRef(CPSV["Active"])


class NonActive(ServiceStatus):
    def __init__(self):
        self.uriRef = URIRef(CPSV["NonActive"])


class UnderDev(ServiceStatus):
    def __init__(self):
        self.uriRef = URIRef(CPSV["UnderDev"])



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .MeasurementUnit import MeasurementUnit
    from .Value import Value


class MeasureType(Characteristic):
    __type__ = MU["MeasureType"]

    hasMeasurementUnit: List[MeasurementUnit] = None
    isMeasureTypeOf: List(Value) = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasMeasurementUnit:
            for hasMeasurementUnit in self.hasMeasurementUnit:
                g.add((self.uriRef, MU["hasMeasurementUnit"],
                       hasMeasurementUnit.uriRef))

        if self.isMeasureTypeOf:
            for isMeasureTypeOf in self.isMeasureTypeOf:
                g.add((self.uriRef, MU["isMeasureTypeOf"],
                       isMeasureTypeOf.uriRef))



from typing import List

from rdflib import RDF, Graph, Literal, Namespace, URIRef
from rdflib.namespace import DC, RDF, RDFS, SKOS


class ConceptScheme:
    label: List[Literal] = []
    creator: List[Literal] = []
    description: List[Literal] = []
    comment: List[Literal] = []

    def __init__(self, uri: Namespace = None):
        self.uriRef = URIRef(uri)

    def addToGraph(self, g: Graph):
        g.add((self.uriRef, RDF.type, SKOS.ConceptScheme))

        self._addProperties(g)

    def _addProperties(self, g: Graph):
        if self.label:
            for label in self.label:
                g.add((self.uriRef, RDFS.label, label))

        if self.creator:
            for creator in self.creator:
                g.add((self.uriRef, DC.creator, creator))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, DC.description, description))

        if self.comment:
            for comment in self.comment:
                g.add((self.uriRef, RDFS.comment, comment))
